@@ -33,6 +33,8 @@
 #include "viralloc.h"
 #include "virstring.h"
 
+VIR_LOG_INIT("conf.domain_audit");
+
 /* Return nn:mm in hex for block and character devices, and NULL
  * for other file types, stat failure, or allocation failure.  */
 #if defined major && defined minor
@@ -126,7 +128,7 @@ virDomainAuditDisk(virDomainObjPtr vm,
               virt, reason, vmname, uuidstr,
               oldsrc, newsrc);
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(oldsrc);
     VIR_FREE(newsrc);
@@ -207,13 +209,13 @@ virDomainAuditRNG(virDomainObjPtr vm,
               virt, reason, vmname, uuidstr,
               oldsrc, newsrc);
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(oldsrc);
     VIR_FREE(newsrc);
     return;
 
-no_memory:
+ no_memory:
     VIR_WARN("OOM while encoding audit message");
     goto cleanup;
 }
@@ -259,7 +261,7 @@ virDomainAuditFS(virDomainObjPtr vm,
               virt, reason, vmname, uuidstr,
               oldsrc, newsrc);
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(oldsrc);
     VIR_FREE(newsrc);
@@ -343,7 +345,7 @@ virDomainAuditNetDevice(virDomainDefPtr vmDef, virDomainNetDefPtr netDef,
               "virt=%s resrc=net reason=open %s uuid=%s net=%s %s rdev=%s",
               virt, vmname, uuidstr, macstr, dev_name, VIR_AUDIT_STR(rdev));
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(dev_name);
     VIR_FREE(rdev);
@@ -467,7 +469,7 @@ virDomainAuditHostdev(virDomainObjPtr vm, virDomainHostdevDefPtr hostdev,
         goto cleanup;
     }
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(device);
     VIR_FREE(address);
@@ -528,7 +530,7 @@ virDomainAuditRedirdev(virDomainObjPtr vm, virDomainRedirdevDefPtr redirdev,
               virDomainRedirdevBusTypeToString(redirdev->bus),
               device);
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(device);
     VIR_FREE(address);
@@ -581,7 +583,7 @@ virDomainAuditTPM(virDomainObjPtr vm, virDomainTPMDefPtr tpm,
         break;
     }
 
-cleanup:
+ cleanup:
     VIR_FREE(vmname);
     VIR_FREE(device);
 }
@@ -702,7 +704,7 @@ virDomainAuditCgroupPath(virDomainObjPtr vm, virCgroupPtr cgroup,
 
     virDomainAuditCgroup(vm, cgroup, reason, extra, rc == 0);
 
-cleanup:
+ cleanup:
     VIR_FREE(extra);
     VIR_FREE(detail);
     VIR_FREE(rdev);
@@ -797,9 +799,10 @@ virDomainAuditStart(virDomainObjPtr vm, const char *reason, bool success)
     size_t i;
 
     for (i = 0; i < vm->def->ndisks; i++) {
-        virDomainDiskDefPtr disk = vm->def->disks[i];
-        if (disk->src) /* Skips CDROM without media initially inserted */
-            virDomainAuditDisk(vm, NULL, disk->src, "start", true);
+        const char *src = virDomainDiskGetSource(vm->def->disks[i]);
+
+        if (src) /* Skips CDROM without media initially inserted */
+            virDomainAuditDisk(vm, NULL, src, "start", true);
     }
 
     for (i = 0; i < vm->def->nfss; i++) {
