@@ -1,7 +1,7 @@
 /*
  * snapshot_conf.c: domain snapshot XML processing
  *
- * Copyright (C) 2006-2013 Red Hat, Inc.
+ * Copyright (C) 2006-2014 Red Hat, Inc.
  * Copyright (C) 2006-2008 Daniel P. Berrange
  *
  * This library is free software; you can redistribute it and/or
@@ -50,6 +50,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_DOMAIN_SNAPSHOT
 
+VIR_LOG_INIT("conf.snapshot_conf");
+
 VIR_ENUM_IMPL(virDomainSnapshotLocation, VIR_DOMAIN_SNAPSHOT_LOCATION_LAST,
               "default",
               "no",
@@ -82,6 +84,9 @@ virDomainSnapshotDiskDefClear(virDomainSnapshotDiskDefPtr disk)
 {
     VIR_FREE(disk->name);
     VIR_FREE(disk->file);
+    while (disk->nhosts)
+        virDomainDiskHostDefClear(&disk->hosts[--disk->nhosts]);
+    VIR_FREE(disk->hosts);
 }
 
 void virDomainSnapshotDefFree(virDomainSnapshotDefPtr def)
@@ -178,7 +183,7 @@ virDomainSnapshotDiskDefParseXML(xmlNodePtr node,
         def->snapshot = VIR_DOMAIN_SNAPSHOT_LOCATION_EXTERNAL;
 
     ret = 0;
-cleanup:
+ cleanup:
     VIR_FREE(snapshot);
     VIR_FREE(type);
     if (ret < 0)
@@ -352,7 +357,7 @@ virDomainSnapshotDefParse(xmlXPathContextPtr ctxt,
 
     ret = def;
 
-cleanup:
+ cleanup:
     VIR_FREE(creation);
     VIR_FREE(state);
     VIR_FREE(nodes);
@@ -389,7 +394,7 @@ virDomainSnapshotDefParseNode(xmlDocPtr xml,
     ctxt->node = root;
     def = virDomainSnapshotDefParse(ctxt, caps, xmlopt,
                                     expectedVirtTypes, flags);
-cleanup:
+ cleanup:
     xmlXPathFreeContext(ctxt);
     return def;
 }
@@ -553,7 +558,7 @@ virDomainSnapshotAlignDisks(virDomainSnapshotDefPtr def,
 
         if (disk->snapshot == VIR_DOMAIN_SNAPSHOT_LOCATION_EXTERNAL &&
             !disk->file) {
-            const char *original = def->dom->disks[i]->src;
+            const char *original = virDomainDiskGetSource(def->dom->disks[i]);
             const char *tmp;
             struct stat sb;
 
@@ -601,7 +606,7 @@ virDomainSnapshotAlignDisks(virDomainSnapshotDefPtr def,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virBitmapFree(map);
     return ret;
 }
@@ -615,7 +620,7 @@ virDomainSnapshotDiskDefFormat(virBufferPtr buf,
     if (!disk->name)
         return;
 
-    virBufferEscapeString(buf, "    <disk name='%s'", disk->name);
+    virBufferEscapeString(buf, "<disk name='%s'", disk->name);
     if (disk->snapshot > 0)
         virBufferAsprintf(buf, " snapshot='%s'",
                           virDomainSnapshotLocationTypeToString(disk->snapshot));
@@ -626,9 +631,10 @@ virDomainSnapshotDiskDefFormat(virBufferPtr buf,
     }
 
     virBufferAsprintf(buf, " type='%s'>\n", virDomainDiskTypeToString(type));
+    virBufferAdjustIndent(buf, 2);
 
     if (disk->format > 0)
-        virBufferEscapeString(buf, "      <driver type='%s'/>\n",
+        virBufferEscapeString(buf, "<driver type='%s'/>\n",
                               virStorageFileFormatTypeToString(disk->format));
     virDomainDiskSourceDefFormatInternal(buf,
                                          type,
@@ -639,7 +645,8 @@ virDomainSnapshotDiskDefFormat(virBufferPtr buf,
                                          disk->hosts,
                                          0, NULL, NULL, 0);
 
-    virBufferAddLit(buf, "    </disk>\n");
+    virBufferAdjustIndent(buf, -2);
+    virBufferAddLit(buf, "</disk>\n");
 }
 
 char *virDomainSnapshotDefFormat(const char *domain_uuid,
@@ -656,45 +663,51 @@ char *virDomainSnapshotDefFormat(const char *domain_uuid,
     flags |= VIR_DOMAIN_XML_INACTIVE;
 
     virBufferAddLit(&buf, "<domainsnapshot>\n");
-    virBufferEscapeString(&buf, "  <name>%s</name>\n", def->name);
+    virBufferAdjustIndent(&buf, 2);
+    virBufferEscapeString(&buf, "<name>%s</name>\n", def->name);
     if (def->description)
-        virBufferEscapeString(&buf, "  <description>%s</description>\n",
+        virBufferEscapeString(&buf, "<description>%s</description>\n",
                               def->description);
-    virBufferAsprintf(&buf, "  <state>%s</state>\n",
+    virBufferAsprintf(&buf, "<state>%s</state>\n",
                       virDomainSnapshotStateTypeToString(def->state));
     if (def->parent) {
-        virBufferAddLit(&buf, "  <parent>\n");
-        virBufferEscapeString(&buf, "    <name>%s</name>\n", def->parent);
-        virBufferAddLit(&buf, "  </parent>\n");
+        virBufferAddLit(&buf, "<parent>\n");
+        virBufferAdjustIndent(&buf, 2);
+        virBufferEscapeString(&buf, "<name>%s</name>\n", def->parent);
+        virBufferAdjustIndent(&buf, -2);
+        virBufferAddLit(&buf, "</parent>\n");
     }
-    virBufferAsprintf(&buf, "  <creationTime>%lld</creationTime>\n",
+    virBufferAsprintf(&buf, "<creationTime>%lld</creationTime>\n",
                       def->creationTime);
     if (def->memory) {
-        virBufferAsprintf(&buf, "  <memory snapshot='%s'",
+        virBufferAsprintf(&buf, "<memory snapshot='%s'",
                           virDomainSnapshotLocationTypeToString(def->memory));
         virBufferEscapeString(&buf, " file='%s'", def->file);
         virBufferAddLit(&buf, "/>\n");
     }
     if (def->ndisks) {
-        virBufferAddLit(&buf, "  <disks>\n");
+        virBufferAddLit(&buf, "<disks>\n");
+        virBufferAdjustIndent(&buf, 2);
         for (i = 0; i < def->ndisks; i++)
             virDomainSnapshotDiskDefFormat(&buf, &def->disks[i]);
-        virBufferAddLit(&buf, "  </disks>\n");
+        virBufferAdjustIndent(&buf, -2);
+        virBufferAddLit(&buf, "</disks>\n");
     }
     if (def->dom) {
-        virBufferAdjustIndent(&buf, 2);
         if (virDomainDefFormatInternal(def->dom, flags, &buf) < 0) {
             virBufferFreeAndReset(&buf);
             return NULL;
         }
-        virBufferAdjustIndent(&buf, -2);
     } else if (domain_uuid) {
-        virBufferAddLit(&buf, "  <domain>\n");
-        virBufferAsprintf(&buf, "    <uuid>%s</uuid>\n", domain_uuid);
-        virBufferAddLit(&buf, "  </domain>\n");
+        virBufferAddLit(&buf, "<domain>\n");
+        virBufferAdjustIndent(&buf, 2);
+        virBufferAsprintf(&buf, "<uuid>%s</uuid>\n", domain_uuid);
+        virBufferAdjustIndent(&buf, -2);
+        virBufferAddLit(&buf, "</domain>\n");
     }
     if (internal)
-        virBufferAsprintf(&buf, "  <active>%d</active>\n", def->current);
+        virBufferAsprintf(&buf, "<active>%d</active>\n", def->current);
+    virBufferAdjustIndent(&buf, -2);
     virBufferAddLit(&buf, "</domainsnapshot>\n");
 
     if (virBufferError(&buf)) {
@@ -1107,7 +1120,7 @@ virDomainListSnapshots(virDomainSnapshotObjListPtr snapshots,
     ret = count;
     *snaps = list;
 
-cleanup:
+ cleanup:
     for (i = 0; i < count; i++)
         VIR_FREE(names[i]);
     VIR_FREE(names);
@@ -1288,7 +1301,7 @@ virDomainSnapshotRedefinePrep(virDomainPtr domain,
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     return ret;
 }
 
