@@ -1,7 +1,7 @@
 /*
  * domain_lock.c: Locking for domain lifecycle operations
  *
- * Copyright (C) 2010-2011 Red Hat, Inc.
+ * Copyright (C) 2010-2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_LOCKING
 
+VIR_LOG_INIT("locking.domain_lock");
+
 
 static int virDomainLockManagerAddLease(virLockManagerPtr lock,
                                         virDomainLeaseDefPtr lease)
@@ -70,12 +72,15 @@ static int virDomainLockManagerAddDisk(virLockManagerPtr lock,
                                        virDomainDiskDefPtr disk)
 {
     unsigned int diskFlags = 0;
-    if (!disk->src)
+    const char *src = virDomainDiskGetSource(disk);
+    int type = virDomainDiskGetType(disk);
+
+    if (!src)
         return 0;
 
-    if (!(disk->type == VIR_DOMAIN_DISK_TYPE_BLOCK ||
-          disk->type == VIR_DOMAIN_DISK_TYPE_FILE ||
-          disk->type == VIR_DOMAIN_DISK_TYPE_DIR))
+    if (!(type == VIR_DOMAIN_DISK_TYPE_BLOCK ||
+          type == VIR_DOMAIN_DISK_TYPE_FILE ||
+          type == VIR_DOMAIN_DISK_TYPE_DIR))
         return 0;
 
     if (disk->readonly)
@@ -83,14 +88,14 @@ static int virDomainLockManagerAddDisk(virLockManagerPtr lock,
     if (disk->shared)
         diskFlags |= VIR_LOCK_MANAGER_RESOURCE_SHARED;
 
-    VIR_DEBUG("Add disk %s", disk->src);
+    VIR_DEBUG("Add disk %s", src);
     if (virLockManagerAddResource(lock,
                                   VIR_LOCK_MANAGER_RESOURCE_TYPE_DISK,
-                                  disk->src,
+                                  src,
                                   0,
                                   NULL,
                                   diskFlags) < 0) {
-        VIR_DEBUG("Failed add disk %s", disk->src);
+        VIR_DEBUG("Failed add disk %s", src);
         return -1;
     }
     return 0;
@@ -150,7 +155,7 @@ static virLockManagerPtr virDomainLockManagerNew(virLockManagerPluginPtr plugin,
 
     return lock;
 
-error:
+ error:
     virLockManagerFree(lock);
     return NULL;
 }
@@ -265,7 +270,7 @@ int virDomainLockDiskAttach(virLockManagerPluginPtr plugin,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virLockManagerFree(lock);
 
     return ret;
@@ -292,7 +297,7 @@ int virDomainLockDiskDetach(virLockManagerPluginPtr plugin,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virLockManagerFree(lock);
 
     return ret;
@@ -322,7 +327,7 @@ int virDomainLockLeaseAttach(virLockManagerPluginPtr plugin,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virLockManagerFree(lock);
 
     return ret;
@@ -349,7 +354,7 @@ int virDomainLockLeaseDetach(virLockManagerPluginPtr plugin,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virLockManagerFree(lock);
 
     return ret;
