@@ -54,6 +54,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_LOCKING
 
+VIR_LOG_INIT("locking.lock_daemon");
+
 #define VIR_LOCK_DAEMON_NUM_LOCKSPACES 3
 
 struct _virLockDaemon {
@@ -145,7 +147,7 @@ virLockDaemonNew(virLockDaemonConfigPtr config, bool privileged)
     }
 
     if (!(lockd->srv = virNetServerNew(1, 1, 0, config->max_clients,
-                                       -1, 0,
+                                       config->max_clients, -1, 0,
                                        false, NULL,
                                        virLockDaemonClientNew,
                                        virLockDaemonClientPreExecRestart,
@@ -162,7 +164,7 @@ virLockDaemonNew(virLockDaemonConfigPtr config, bool privileged)
 
     return lockd;
 
-error:
+ error:
     virLockDaemonFree(lockd);
     return NULL;
 }
@@ -244,7 +246,7 @@ virLockDaemonNewPostExecRestart(virJSONValuePtr object, bool privileged)
 
     return lockd;
 
-error:
+ error:
     virLockDaemonFree(lockd);
     return NULL;
 }
@@ -394,7 +396,7 @@ virLockDaemonPidFilePath(bool privileged,
 
     return 0;
 
-error:
+ error:
     return -1;
 }
 
@@ -429,7 +431,7 @@ virLockDaemonUnixSocketPaths(bool privileged,
     }
     return 0;
 
-error:
+ error:
     return -1;
 }
 
@@ -476,8 +478,6 @@ virLockDaemonSetupLogging(virLockDaemonConfigPtr config,
 
     virLogSetFromEnv();
 
-    virLogSetBufferSize(config->log_buffer_size);
-
     if (virLogGetNbFilters() == 0)
         virLogParseFilters(config->log_filters);
 
@@ -551,7 +551,7 @@ virLockDaemonSetupLogging(virLockDaemonConfigPtr config,
 
     return 0;
 
-error:
+ error:
     return -1;
 }
 
@@ -816,7 +816,7 @@ virLockDaemonClientNew(virNetServerClientPtr client,
 
     return priv;
 
-error:
+ error:
     virMutexDestroy(&priv->lock);
     VIR_FREE(priv);
     return NULL;
@@ -871,7 +871,7 @@ virLockDaemonClientNewPostExecRestart(virNetServerClientPtr client,
     }
     return priv;
 
-error:
+ error:
     virLockDaemonClientFree(priv);
     return NULL;
 }
@@ -917,7 +917,7 @@ virLockDaemonClientPreExecRestart(virNetServerClientPtr client ATTRIBUTE_UNUSED,
 
     return object;
 
-error:
+ error:
     virJSONValueFree(object);
     return NULL;
 }
@@ -955,7 +955,7 @@ virLockDaemonExecRestartStatePath(bool privileged,
 
     return 0;
 
-error:
+ error:
     return -1;
 }
 
@@ -1020,7 +1020,7 @@ virLockDaemonPostExecRestart(const char *state_file,
 
     /* Re-claim PID file now as we will not be daemonizing */
     if (pid_file &&
-        (*pid_file_fd = virPidFileAcquirePath(pid_file, getpid())) < 0)
+        (*pid_file_fd = virPidFileAcquirePath(pid_file, false, getpid())) < 0)
         goto cleanup;
 
     if (!(lockDaemon = virLockDaemonNewPostExecRestart(object, privileged)))
@@ -1028,7 +1028,7 @@ virLockDaemonPostExecRestart(const char *state_file,
 
     ret = 1;
 
-cleanup:
+ cleanup:
     unlink(state_file);
     VIR_FREE(wantmagic);
     VIR_FREE(state);
@@ -1123,7 +1123,7 @@ virLockDaemonPreExecRestart(const char *state_file,
 
     abort(); /* This should be impossible to reach */
 
-cleanup:
+ cleanup:
     VIR_FREE(pairs);
     VIR_FREE(state);
     virJSONValueFree(object);
@@ -1382,7 +1382,7 @@ int main(int argc, char **argv) {
         }
 
         /* If we have a pidfile set, claim it now, exiting if already taken */
-        if ((pid_file_fd = virPidFileAcquirePath(pid_file, getpid())) < 0) {
+        if ((pid_file_fd = virPidFileAcquirePath(pid_file, false, getpid())) < 0) {
             ret = VIR_LOCK_DAEMON_ERR_PIDFILE;
             goto cleanup;
         }
@@ -1451,7 +1451,7 @@ int main(int argc, char **argv) {
     else
         ret = 0;
 
-cleanup:
+ cleanup:
     virObjectUnref(lockProgram);
     virLockDaemonFree(lockDaemon);
     if (statuswrite != -1) {
@@ -1472,7 +1472,7 @@ cleanup:
     VIR_FREE(run_dir);
     return ret;
 
-no_memory:
+ no_memory:
     VIR_ERROR(_("Can't allocate memory"));
     exit(EXIT_FAILURE);
 }
