@@ -1,5 +1,5 @@
 /*
- * bridge_driver.h: platform specific routines for bridge driver
+ * bridge_driver_platform.h: platform specific routines for bridge driver
  *
  * Copyright (C) 2006-2013 Red Hat, Inc.
  * Copyright (C) 2006 Daniel P. Berrange
@@ -25,7 +25,6 @@
 # define __VIR_BRIDGE_DRIVER_PLATFORM_H__
 
 # include "internal.h"
-# include "virlog.h"
 # include "virthread.h"
 # include "virdnsmasq.h"
 # include "network_conf.h"
@@ -53,28 +52,6 @@ typedef virNetworkDriverState *virNetworkDriverStatePtr;
 
 int networkCheckRouteCollision(virNetworkObjPtr network);
 
-int networkAddMasqueradingFirewallRules(virNetworkObjPtr network,
-                                        virNetworkIpDefPtr ipdef);
-
-void networkRemoveMasqueradingFirewallRules(virNetworkObjPtr network,
-                                            virNetworkIpDefPtr ipdef);
-
-int networkAddRoutingFirewallRules(virNetworkObjPtr network,
-                                   virNetworkIpDefPtr ipdef);
-
-void networkRemoveRoutingFirewallRules(virNetworkObjPtr network,
-                                       virNetworkIpDefPtr ipdef);
-
-int networkAddGeneralFirewallRules(virNetworkObjPtr network);
-
-void networkRemoveGeneralFirewallRules(virNetworkObjPtr network);
-
-int networkAddIpSpecificFirewallRules(virNetworkObjPtr network,
-                                      virNetworkIpDefPtr ipdef);
-
-void networkRemoveIpSpecificFirewallRules(virNetworkObjPtr network,
-                                          virNetworkIpDefPtr ipdef);
-
 int networkAddFirewallRules(virNetworkObjPtr network);
 
 void networkRemoveFirewallRules(virNetworkObjPtr network);
