@@ -115,7 +115,7 @@ parallelsFindVolumes(virStoragePoolObjPtr pool)
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     VIR_FREE(path);
     closedir(dir);
     return ret;
@@ -194,7 +194,7 @@ parallelsPoolCreateByPath(virConnectPtr conn, const char *path)
     virStoragePoolObjUnlock(pool);
 
     return pool;
-error:
+ error:
     virStoragePoolDefFree(def);
     if (pool)
         virStoragePoolObjUnlock(pool);
@@ -267,7 +267,7 @@ static int parallelsDiskDescParseNode(xmlDocPtr xml,
     def->capacity <<= 9;
     def->allocation = def->capacity;
     ret = 0;
-cleanup:
+ cleanup:
     xmlXPathFreeContext(ctxt);
     return ret;
 
@@ -311,15 +311,13 @@ static int parallelsAddDiskVolume(virStoragePoolObjPtr pool,
     if (VIR_STRDUP(def->key, def->target.path) < 0)
         goto error;
 
-    if (VIR_REALLOC_N(pool->volumes.objs, pool->volumes.count + 1) < 0)
+    if (VIR_APPEND_ELEMENT(pool->volumes.objs, pool->volumes.count, def) < 0)
         goto error;
 
-    pool->volumes.objs[pool->volumes.count++] = def;
-
     return 0;
-no_memory:
+ no_memory:
     virReportOOMError();
-error:
+ error:
     virStorageVolDefFree(def);
     return -1;
 }
@@ -374,7 +372,7 @@ static int parallelsFindVmVolumes(virStoragePoolObjPtr pool,
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     VIR_FREE(diskPath);
     VIR_FREE(diskDescPath);
     closedir(dir);
@@ -448,7 +446,7 @@ static int parallelsLoadPools(virConnectPtr conn)
 
     return 0;
 
-error:
+ error:
     VIR_FREE(base);
     return -1;
 }
@@ -482,7 +480,7 @@ parallelsStorageOpen(virConnectPtr conn,
 
     return VIR_DRV_OPEN_SUCCESS;
 
-error:
+ error:
     parallelsStorageUnlock(storageState);
     parallelsStorageClose(conn);
     return -1;
@@ -526,7 +524,7 @@ parallelsConnectListStoragePools(virConnectPtr conn, char **const names, int nna
 
     return n;
 
-error:
+ error:
     for (n = 0; n < nnames; n++)
         VIR_FREE(names[n]);
     parallelsDriverUnlock(privconn);
@@ -575,7 +573,7 @@ parallelsConnectListDefinedStoragePools(virConnectPtr conn,
 
     return n;
 
-error:
+ error:
     for (n = 0; n < nnames; n++)
         VIR_FREE(names[n]);
     parallelsDriverUnlock(privconn);
@@ -599,7 +597,7 @@ parallelsStoragePoolIsActive(virStoragePoolPtr pool)
     }
     ret = virStoragePoolObjIsActive(obj);
 
-cleanup:
+ cleanup:
     if (obj)
         virStoragePoolObjUnlock(obj);
     return ret;
@@ -630,7 +628,7 @@ parallelsStoragePoolLookupByUUID(virConnectPtr conn, const unsigned char *uuid)
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -655,7 +653,7 @@ parallelsStoragePoolLookupByName(virConnectPtr conn, const char *name)
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -738,7 +736,7 @@ parallelsStoragePoolDefineXML(virConnectPtr conn,
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     virStoragePoolDefFree(def);
     if (pool)
         virStoragePoolObjUnlock(pool);
@@ -775,7 +773,7 @@ parallelsStoragePoolUndefine(virStoragePoolPtr pool)
     virStoragePoolObjRemove(&privconn->pools, privpool);
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     parallelsDriverUnlock(privconn);
@@ -809,7 +807,7 @@ parallelsStoragePoolCreate(virStoragePoolPtr pool, unsigned int flags)
     privpool->active = 1;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -842,7 +840,7 @@ parallelsStoragePoolDestroy(virStoragePoolPtr pool)
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     parallelsDriverUnlock(privconn);
@@ -874,7 +872,7 @@ parallelsStoragePoolRefresh(virStoragePoolPtr pool, unsigned int flags)
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -907,7 +905,7 @@ parallelsStoragePoolGetInfo(virStoragePoolPtr pool, virStoragePoolInfoPtr info)
     info->available = privpool->def->available;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -933,7 +931,7 @@ parallelsStoragePoolGetXMLDesc(virStoragePoolPtr pool, unsigned int flags)
 
     ret = virStoragePoolDefFormat(privpool->def);
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -962,7 +960,7 @@ parallelsStoragePoolGetAutostart(virStoragePoolPtr pool, int *autostart)
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -992,7 +990,7 @@ parallelsStoragePoolSetAutostart(virStoragePoolPtr pool, int autostart)
     privpool->autostart = (autostart != 0);
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1022,7 +1020,7 @@ parallelsStoragePoolNumOfVolumes(virStoragePoolPtr pool)
 
     ret = privpool->volumes.count;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1063,7 +1061,7 @@ parallelsStoragePoolListVolumes(virStoragePoolPtr pool,
     virStoragePoolObjUnlock(privpool);
     return n;
 
-error:
+ error:
     for (n = 0; n < maxnames; n++)
         VIR_FREE(names[i]);
 
@@ -1109,7 +1107,7 @@ parallelsStorageVolLookupByName(virStoragePoolPtr pool,
                            privvol->name, privvol->key,
                            NULL, NULL);
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1229,9 +1227,6 @@ parallelsStorageVolDefineXML(virStoragePoolObjPtr pool,
         }
     }
 
-    if (VIR_REALLOC_N(pool->volumes.objs, pool->volumes.count + 1) < 0)
-        goto cleanup;
-
     if (virAsprintf(&privvol->target.path, "%s/%s",
                     pool->def->target.path, privvol->name) < 0)
         goto cleanup;
@@ -1255,12 +1250,14 @@ parallelsStorageVolDefineXML(virStoragePoolObjPtr pool,
                                 pool->def->allocation);
     }
 
-    pool->volumes.objs[pool->volumes.count++] = privvol;
+    if (VIR_APPEND_ELEMENT_COPY(pool->volumes.objs,
+                                pool->volumes.count, privvol) < 0)
+        goto cleanup;
 
     ret = privvol;
     privvol = NULL;
 
-cleanup:
+ cleanup:
     virStorageVolDefFree(privvol);
     VIR_FREE(xml_path);
     return ret;
@@ -1299,7 +1296,7 @@ parallelsStorageVolCreateXML(virStoragePoolPtr pool,
     ret = virGetStorageVol(pool->conn, privpool->def->name,
                            privvol->name, privvol->key,
                            NULL, NULL);
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1362,10 +1359,6 @@ parallelsStorageVolCreateXMLFrom(virStoragePoolPtr pool,
     privpool->def->available = (privpool->def->capacity -
                                 privpool->def->allocation);
 
-    if (VIR_REALLOC_N(privpool->volumes.objs,
-                      privpool->volumes.count + 1) < 0)
-        goto cleanup;
-
     if (virAsprintf(&privvol->target.path, "%s/%s",
                     privpool->def->target.path, privvol->name) == -1)
         goto cleanup;
@@ -1377,14 +1370,16 @@ parallelsStorageVolCreateXMLFrom(virStoragePoolPtr pool,
     privpool->def->available = (privpool->def->capacity -
                                 privpool->def->allocation);
 
-    privpool->volumes.objs[privpool->volumes.count++] = privvol;
+    if (VIR_APPEND_ELEMENT_COPY(privpool->volumes.objs,
+                                privpool->volumes.count, privvol) < 0)
+        goto cleanup;
 
     ret = virGetStorageVol(pool->conn, privpool->def->name,
                            privvol->name, privvol->key,
                            NULL, NULL);
     privvol = NULL;
 
-cleanup:
+ cleanup:
     virStorageVolDefFree(privvol);
     if (privpool)
         virStoragePoolObjUnlock(privpool);
@@ -1416,24 +1411,13 @@ int parallelsStorageVolDefRemove(virStoragePoolObjPtr privpool,
 
             virStorageVolDefFree(privvol);
 
-            if (i < (privpool->volumes.count - 1))
-                memmove(privpool->volumes.objs + i,
-                        privpool->volumes.objs + i + 1,
-                        sizeof(*(privpool->volumes.objs)) *
-                        (privpool->volumes.count - (i + 1)));
-
-            if (VIR_REALLOC_N(privpool->volumes.objs,
-                              privpool->volumes.count - 1) < 0) {
-                ;   /* Failure to reduce memory allocation isn't fatal */
-            }
-            privpool->volumes.count--;
-
+            VIR_DELETE_ELEMENT(privpool->volumes.objs, i, privpool->volumes.count);
             break;
         }
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     VIR_FREE(xml_path);
     return ret;
 }
@@ -1478,7 +1462,7 @@ parallelsStorageVolDelete(virStorageVolPtr vol, unsigned int flags)
 
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1494,7 +1478,7 @@ parallelsStorageVolTypeForPool(int pooltype)
         case VIR_STORAGE_POOL_FS:
         case VIR_STORAGE_POOL_NETFS:
             return VIR_STORAGE_VOL_FILE;
-default:
+ default:
             return VIR_STORAGE_VOL_BLOCK;
     }
 }
@@ -1536,7 +1520,7 @@ parallelsStorageVolGetInfo(virStorageVolPtr vol, virStorageVolInfoPtr info)
     info->allocation = privvol->allocation;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1577,7 +1561,7 @@ parallelsStorageVolGetXMLDesc(virStorageVolPtr vol, unsigned int flags)
 
     ret = virStorageVolDefFormat(privpool->def, privvol);
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
@@ -1616,7 +1600,7 @@ parallelsStorageVolGetPath(virStorageVolPtr vol)
 
     ignore_value(VIR_STRDUP(ret, privvol->target.path));
 
-cleanup:
+ cleanup:
     if (privpool)
         virStoragePoolObjUnlock(privpool);
     return ret;
