@@ -1,7 +1,7 @@
 /*
- * qemu_agent.h: interaction with QEMU guest agent
+ * qemu_agent.c: interaction with QEMU guest agent
  *
- * Copyright (C) 2006-2013 Red Hat, Inc.
+ * Copyright (C) 2006-2014 Red Hat, Inc.
  * Copyright (C) 2006 Daniel P. Berrange
  *
  * This library is free software; you can redistribute it and/or
@@ -45,6 +45,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_QEMU
 
+VIR_LOG_INIT("qemu.qemu_agent");
+
 #define LINE_ENDING "\n"
 
 #define DEBUG_IO 0
@@ -238,7 +240,7 @@ qemuAgentOpenUnix(const char *monitor, pid_t cpid, bool *inProgress)
 
     return monfd;
 
-error:
+ error:
     VIR_FORCE_CLOSE(monfd);
     return -1;
 }
@@ -262,7 +264,7 @@ qemuAgentOpenPty(const char *monitor)
 
     return monfd;
 
-error:
+ error:
     VIR_FORCE_CLOSE(monfd);
     return -1;
 }
@@ -350,7 +352,7 @@ qemuAgentIOProcessLine(qemuAgentPtr mon,
                        _("Unknown JSON reply '%s'"), line);
     }
 
-cleanup:
+ cleanup:
     virJSONValueFree(obj);
     return ret;
 }
@@ -572,7 +574,8 @@ static void qemuAgentUpdateWatch(qemuAgentPtr mon)
 
 
 static void
-qemuAgentIO(int watch, int fd, int events, void *opaque) {
+qemuAgentIO(int watch, int fd, int events, void *opaque)
+{
     qemuAgentPtr mon = opaque;
     bool error = false;
     bool eof = false;
@@ -774,7 +777,7 @@ qemuAgentOpen(virDomainObjPtr vm,
 
     return mon;
 
-cleanup:
+ cleanup:
     /* We don't want the 'destroy' callback invoked during
      * cleanup from construction failure, because that can
      * give a double-unref on virDomainObjPtr in the caller,
@@ -885,7 +888,7 @@ static int qemuAgentSend(qemuAgentPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     mon->msg = NULL;
     qemuAgentUpdateWatch(mon);
 
@@ -956,7 +959,7 @@ qemuAgentGuestSync(qemuAgentPtr mon)
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     virJSONValueFree(sync_msg.rxObject);
     VIR_FREE(sync_msg.txBuffer);
     return ret;
@@ -1009,7 +1012,7 @@ qemuAgentCommand(qemuAgentPtr mon,
         }
     }
 
-cleanup:
+ cleanup:
     VIR_FREE(cmdstr);
     VIR_FREE(msg.txBuffer);
 
@@ -1223,7 +1226,7 @@ qemuAgentMakeCommand(const char *cmdname,
 
     return obj;
 
-error:
+ error:
     virJSONValueFree(obj);
     virJSONValueFree(jargs);
     va_end(args);
@@ -1314,7 +1317,7 @@ int qemuAgentFSFreeze(qemuAgentPtr mon)
                        _("malformed return value"));
     }
 
-cleanup:
+ cleanup:
     virJSONValueFree(cmd);
     virJSONValueFree(reply);
     return ret;
@@ -1352,7 +1355,7 @@ int qemuAgentFSThaw(qemuAgentPtr mon)
                        _("malformed return value"));
     }
 
-cleanup:
+ cleanup:
     virJSONValueFree(cmd);
     virJSONValueFree(reply);
     return ret;
@@ -1423,7 +1426,7 @@ qemuAgentArbitraryCommand(qemuAgentPtr mon,
         ret = -1;
 
 
-cleanup:
+ cleanup:
     virJSONValueFree(cmd);
     virJSONValueFree(reply);
     return ret;
@@ -1523,7 +1526,7 @@ qemuAgentGetVCPUs(qemuAgentPtr mon,
 
     ret = ndata;
 
-cleanup:
+ cleanup:
     virJSONValueFree(cmd);
     virJSONValueFree(reply);
     return ret;
@@ -1587,7 +1590,7 @@ qemuAgentSetVCPUs(qemuAgentPtr mon,
                        _("malformed return value"));
     }
 
-cleanup:
+ cleanup:
     virJSONValueFree(cmd);
     virJSONValueFree(reply);
     virJSONValueFree(cpu);
