@@ -1,7 +1,7 @@
 /*
  * qemu_monitor_text.c: interaction with QEMU monitor console
  *
- * Copyright (C) 2006-2013 Red Hat, Inc.
+ * Copyright (C) 2006-2014 Red Hat, Inc.
  * Copyright (C) 2006 Daniel P. Berrange
  *
  * This library is free software; you can redistribute it and/or
@@ -40,6 +40,7 @@
 #include "datatypes.h"
 #include "virerror.h"
 #include "virbuffer.h"
+#include "virprobe.h"
 #include "virstring.h"
 
 #ifdef WITH_DTRACE_PROBES
@@ -48,6 +49,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_QEMU
 
+VIR_LOG_INIT("qemu.qemu_monitor_text");
+
 #define QEMU_CMD_PROMPT "\n(qemu) "
 #define QEMU_PASSWD_PROMPT "Password: "
 
@@ -361,7 +364,8 @@ qemuMonitorSendDiskPassphrase(qemuMonitorPtr mon,
 
 int
 qemuMonitorTextStartCPUs(qemuMonitorPtr mon,
-                         virConnectPtr conn) {
+                         virConnectPtr conn)
+{
     char *reply;
 
     if (qemuMonitorTextCommandWithHandler(mon, "cont",
@@ -376,7 +380,8 @@ qemuMonitorTextStartCPUs(qemuMonitorPtr mon,
 
 
 int
-qemuMonitorTextStopCPUs(qemuMonitorPtr mon) {
+qemuMonitorTextStopCPUs(qemuMonitorPtr mon)
+{
     char *info;
     int ret;
 
@@ -425,13 +430,14 @@ qemuMonitorTextGetStatus(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     return ret;
 }
 
 
-int qemuMonitorTextSystemPowerdown(qemuMonitorPtr mon) {
+int qemuMonitorTextSystemPowerdown(qemuMonitorPtr mon)
+{
     char *info;
     int ret;
 
@@ -441,7 +447,11 @@ int qemuMonitorTextSystemPowerdown(qemuMonitorPtr mon) {
     return ret;
 }
 
-int qemuMonitorTextSetLink(qemuMonitorPtr mon, const char *name, enum virDomainNetInterfaceLinkState state) {
+int
+qemuMonitorTextSetLink(qemuMonitorPtr mon,
+                       const char *name,
+                       enum virDomainNetInterfaceLinkState state)
+{
     char *info = NULL;
     char *cmd = NULL;
     const char *st_str = NULL;
@@ -476,14 +486,15 @@ int qemuMonitorTextSetLink(qemuMonitorPtr mon, const char *name, enum virDomainN
     VIR_FREE(cmd);
     return 0;
 
-error:
+ error:
     VIR_FREE(info);
     VIR_FREE(cmd);
 
     return -1;
 }
 
-int qemuMonitorTextSystemReset(qemuMonitorPtr mon) {
+int qemuMonitorTextSystemReset(qemuMonitorPtr mon)
+{
     char *info;
     int ret;
 
@@ -529,11 +540,10 @@ int qemuMonitorTextGetCPUInfo(qemuMonitorPtr mon,
         if (end == NULL || !c_isspace(*end))
             goto error;
 
-        if (VIR_REALLOC_N(cpupids, ncpupids+1) < 0)
+        if (VIR_APPEND_ELEMENT_COPY(cpupids, ncpupids, tid) < 0)
             goto error;
 
         VIR_DEBUG("tid=%d", tid);
-        cpupids[ncpupids++] = tid;
 
         /* Skip to next data line */
         line = strchr(offset, '\r');
@@ -546,7 +556,7 @@ int qemuMonitorTextGetCPUInfo(qemuMonitorPtr mon,
     *pids = cpupids;
     return ncpupids;
 
-error:
+ error:
     VIR_FREE(qemucpus);
     VIR_FREE(cpupids);
 
@@ -697,7 +707,7 @@ int qemuMonitorTextGetBalloonInfo(qemuMonitorPtr mon,
         ret = 0;
     }
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     return ret;
 }
@@ -824,7 +834,7 @@ int qemuMonitorTextGetBlockInfo(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(info);
     VIR_FREE(reply);
     return ret;
@@ -1061,7 +1071,7 @@ int qemuMonitorTextBlockResize(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -1135,7 +1145,7 @@ int qemuMonitorTextSetPassword(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     return ret;
@@ -1164,7 +1174,7 @@ int qemuMonitorTextExpirePassword(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     return ret;
@@ -1266,7 +1276,7 @@ int qemuMonitorTextEjectMedia(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     return ret;
@@ -1310,7 +1320,7 @@ int qemuMonitorTextChangeMedia(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     VIR_FREE(safepath);
@@ -1341,7 +1351,7 @@ static int qemuMonitorTextSaveMemory(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safepath);
@@ -1381,7 +1391,7 @@ int qemuMonitorTextSetMigrationSpeed(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(info);
     VIR_FREE(cmd);
     return ret;
@@ -1403,7 +1413,7 @@ int qemuMonitorTextSetMigrationDowntime(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(info);
     VIR_FREE(cmd);
     return ret;
@@ -1535,10 +1545,10 @@ int qemuMonitorTextGetMigrationStatus(qemuMonitorPtr mon,
         }
     }
 
-done:
+ done:
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     if (ret < 0)
         memset(status, 0, sizeof(*status));
@@ -1597,7 +1607,7 @@ int qemuMonitorTextMigrate(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(extrastr);
     VIR_FREE(safedest);
     VIR_FREE(info);
@@ -1671,7 +1681,7 @@ int qemuMonitorTextAddUSBDisk(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(safepath);
     VIR_FREE(info);
@@ -1702,7 +1712,7 @@ static int qemuMonitorTextAddUSBDevice(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -1838,7 +1848,7 @@ int qemuMonitorTextAddPCIHostDevice(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -1860,7 +1870,7 @@ int qemuMonitorTextAddPCIDisk(qemuMonitorPtr mon,
     if (!safe_path)
         return -1;
 
-try_command:
+ try_command:
     if (virAsprintf(&cmd, "pci_add %s storage file=%s,if=%s",
                     (tryOldSyntax ? "0": "pci_addr=auto"), safe_path, bus) < 0)
         goto cleanup;
@@ -1883,7 +1893,7 @@ try_command:
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(safe_path);
     VIR_FREE(cmd);
     VIR_FREE(reply);
@@ -1913,7 +1923,7 @@ int qemuMonitorTextAddPCINetwork(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     return ret;
@@ -1928,7 +1938,7 @@ int qemuMonitorTextRemovePCIDevice(qemuMonitorPtr mon,
     bool tryOldSyntax = false;
     int ret = -1;
 
-try_command:
+ try_command:
     if (tryOldSyntax) {
         if (virAsprintf(&cmd, "pci_del 0 %.2x", guestAddr->slot) < 0)
             goto cleanup;
@@ -1964,7 +1974,7 @@ try_command:
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2003,7 +2013,7 @@ int qemuMonitorTextSendFileHandle(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2034,7 +2044,7 @@ int qemuMonitorTextCloseFileHandle(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2063,7 +2073,7 @@ int qemuMonitorTextAddHostNetwork(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2088,7 +2098,7 @@ int qemuMonitorTextRemoveHostNetwork(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2112,7 +2122,7 @@ int qemuMonitorTextAddNetdev(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2136,7 +2146,7 @@ int qemuMonitorTextRemoveNetdev(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2219,7 +2229,7 @@ int qemuMonitorTextGetPtyPaths(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     return ret;
 }
@@ -2234,7 +2244,7 @@ int qemuMonitorTextAttachPCIDiskController(qemuMonitorPtr mon,
     bool tryOldSyntax = false;
     int ret = -1;
 
-try_command:
+ try_command:
     if (virAsprintf(&cmd, "pci_add %s storage if=%s",
                     (tryOldSyntax ? "0": "pci_addr=auto"), bus) < 0)
         goto cleanup;
@@ -2257,7 +2267,7 @@ try_command:
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2324,7 +2334,7 @@ int qemuMonitorTextAttachDrive(qemuMonitorPtr mon,
     if (!safe_str)
         return -1;
 
-try_command:
+ try_command:
     if (virAsprintf(&cmd, "drive_add %s%.2x:%.2x:%.2x %s",
                     (tryOldSyntax ? "" : "pci_addr="),
                     controllerAddr->domain, controllerAddr->bus,
@@ -2354,7 +2364,7 @@ try_command:
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safe_str);
@@ -2477,7 +2487,7 @@ int qemuMonitorTextGetAllPCIAddresses(qemuMonitorPtr mon,
 
     return naddrs;
 
-error:
+ error:
     VIR_FREE(addrs);
     VIR_FREE(reply);
     return -1;
@@ -2514,7 +2524,7 @@ int qemuMonitorTextDelDevice(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safedev);
@@ -2557,7 +2567,7 @@ int qemuMonitorTextAddDevice(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safedev);
@@ -2599,7 +2609,7 @@ int qemuMonitorTextAddDrive(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safe_str);
@@ -2645,7 +2655,7 @@ int qemuMonitorTextDriveDel(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safedev);
@@ -2684,7 +2694,7 @@ int qemuMonitorTextSetDrivePassphrase(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     VIR_FREE(safe_str);
@@ -2727,7 +2737,7 @@ int qemuMonitorTextCreateSnapshot(qemuMonitorPtr mon, const char *name)
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(safename);
     VIR_FREE(cmd);
     VIR_FREE(reply);
@@ -2780,7 +2790,7 @@ int qemuMonitorTextLoadSnapshot(qemuMonitorPtr mon, const char *name)
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(safename);
     VIR_FREE(cmd);
     VIR_FREE(reply);
@@ -2817,7 +2827,7 @@ int qemuMonitorTextDeleteSnapshot(qemuMonitorPtr mon, const char *name)
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(safename);
     VIR_FREE(cmd);
     VIR_FREE(reply);
@@ -2908,7 +2918,7 @@ int qemuMonitorTextSendKey(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(reply);
     return ret;
@@ -2934,7 +2944,7 @@ int qemuMonitorTextScreendump(qemuMonitorPtr mon, const char *file)
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     return ret;
@@ -2961,7 +2971,7 @@ int qemuMonitorTextOpenGraphics(qemuMonitorPtr mon,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(reply);
     VIR_FREE(cmd);
     return ret;
@@ -2995,7 +3005,7 @@ int qemuMonitorTextSetBlockIoThrottle(qemuMonitorPtr mon,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
     VIR_FREE(result);
     return ret;
@@ -3072,7 +3082,7 @@ qemuMonitorTextParseBlockIoThrottle(const char *result,
     virReportError(VIR_ERR_INVALID_ARG,
                    _("No info for device '%s'"), device);
 
-cleanup:
+ cleanup:
     return ret;
 }
 
@@ -3095,7 +3105,7 @@ int qemuMonitorTextGetBlockIoThrottle(qemuMonitorPtr mon,
 
     ret = qemuMonitorTextParseBlockIoThrottle(result, device, reply);
 
-cleanup:
+ cleanup:
     VIR_FREE(result);
     return ret;
 }
