@@ -51,6 +51,7 @@
 #include "virlog.h"
 #include "virfile.h"
 #include "virthread.h"
+#include "virprobe.h"
 #include "virprocess.h"
 #include "virstring.h"
 #include "passfd.h"
@@ -61,6 +62,7 @@
 
 #define VIR_FROM_THIS VIR_FROM_RPC
 
+VIR_LOG_INIT("rpc.netsocket");
 
 struct _virNetSocket {
     virObjectLockable parent;
@@ -206,7 +208,7 @@ static virNetSocketPtr virNetSocketNew(virSocketAddrPtr localAddr,
 
     return sock;
 
-error:
+ error:
     sock->fd = sock->errfd = -1; /* Caller owns fd/errfd on failure */
     virObjectUnref(sock);
     return NULL;
@@ -318,7 +320,7 @@ int virNetSocketNewListenTCP(const char *nodename,
     *nretsocks = nsocks;
     return 0;
 
-error:
+ error:
     for (i = 0; i < nsocks; i++)
         virObjectUnref(socks[i]);
     VIR_FREE(socks);
@@ -387,7 +389,7 @@ int virNetSocketNewListenUNIX(const char *path,
 
     return 0;
 
-error:
+ error:
     if (path[0] != '@')
         unlink(path);
     VIR_FORCE_CLOSE(fd);
@@ -504,7 +506,7 @@ int virNetSocketNewConnectTCP(const char *nodename,
 
     return 0;
 
-error:
+ error:
     freeaddrinfo(ai);
     VIR_FORCE_CLOSE(fd);
     return -1;
@@ -546,7 +548,7 @@ int virNetSocketNewConnectUNIX(const char *path,
     if (remoteAddr.data.un.sun_path[0] == '@')
         remoteAddr.data.un.sun_path[0] = '\0';
 
-retry:
+ retry:
     if (connect(fd, &remoteAddr.data.sa, remoteAddr.len) < 0) {
         if ((errno == ECONNREFUSED ||
              errno == ENOENT) &&
@@ -579,7 +581,7 @@ retry:
 
     return 0;
 
-error:
+ error:
     VIR_FORCE_CLOSE(fd);
     return -1;
 }
@@ -640,7 +642,7 @@ int virNetSocketNewConnectCommand(virCommandPtr cmd,
 
     return 0;
 
-error:
+ error:
     VIR_FORCE_CLOSE(sv[0]);
     VIR_FORCE_CLOSE(sv[1]);
     VIR_FORCE_CLOSE(errfd[0]);
@@ -843,7 +845,7 @@ virNetSocketNewConnectLibSSH2(const char *host,
     VIR_FREE(authMethodsCopy);
     return 0;
 
-error:
+ error:
     virObjectUnref(sock);
     virObjectUnref(sess);
     VIR_FREE(authMethodsCopy);
@@ -1005,7 +1007,7 @@ virJSONValuePtr virNetSocketPreExecRestart(virNetSocketPtr sock)
     virObjectUnlock(sock);
     return object;
 
-error:
+ error:
     virObjectUnlock(sock);
     virJSONValueFree(object);
     return NULL;
@@ -1143,7 +1145,7 @@ int virNetSocketGetUNIXIdentity(virNetSocketPtr sock,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virObjectUnlock(sock);
     return ret;
 }
@@ -1228,7 +1230,7 @@ int virNetSocketGetUNIXIdentity(virNetSocketPtr sock,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virObjectUnlock(sock);
     return ret;
 }
@@ -1270,7 +1272,7 @@ int virNetSocketGetSELinuxContext(virNetSocketPtr sock,
         goto cleanup;
 
     ret = 0;
-cleanup:
+ cleanup:
     freecon(seccon);
     virObjectUnlock(sock);
     return ret;
@@ -1409,7 +1411,7 @@ static ssize_t virNetSocketReadWire(virNetSocketPtr sock, char *buf, size_t len)
         return virNetSocketLibSSH2Read(sock, buf, len);
 #endif
 
-reread:
+ reread:
 #if WITH_GNUTLS
     if (sock->tlsSession &&
         virNetTLSSessionGetHandshakeStatus(sock->tlsSession) ==
@@ -1468,7 +1470,7 @@ static ssize_t virNetSocketWriteWire(virNetSocketPtr sock, const char *buf, size
         return virNetSocketLibSSH2Write(sock, buf, len);
 #endif
 
-rewrite:
+ rewrite:
 #if WITH_GNUTLS
     if (sock->tlsSession &&
         virNetTLSSessionGetHandshakeStatus(sock->tlsSession) ==
@@ -1653,7 +1655,7 @@ int virNetSocketSendFD(virNetSocketPtr sock, int fd)
     }
     ret = 1;
 
-cleanup:
+ cleanup:
     virObjectUnlock(sock);
     return ret;
 }
@@ -1687,7 +1689,7 @@ int virNetSocketRecvFD(virNetSocketPtr sock, int *fd)
           "sock=%p fd=%d", sock, *fd);
     ret = 1;
 
-cleanup:
+ cleanup:
     virObjectUnlock(sock);
     return ret;
 }
@@ -1747,7 +1749,7 @@ int virNetSocketAccept(virNetSocketPtr sock, virNetSocketPtr *clientsock)
     fd = -1;
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FORCE_CLOSE(fd);
     virObjectUnlock(sock);
     return ret;
@@ -1822,7 +1824,7 @@ int virNetSocketAddIOCallback(virNetSocketPtr sock,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virObjectUnlock(sock);
     if (ret != 0)
         virObjectUnref(sock);
