@@ -37,6 +37,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_STORAGE
 
+VIR_LOG_INIT("storage.storage_backend_rbd");
+
 struct _virStorageBackendRBDState {
     rados_t cluster;
     rados_ioctx_t ioctx;
@@ -224,7 +226,7 @@ static int virStorageBackendRBDOpenRADOSConn(virStorageBackendRBDStatePtr ptr,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(secret_value);
     VIR_FREE(rados_key);
 
@@ -316,7 +318,7 @@ static int volStorageBackendRBDRefreshVolInfo(virStorageVolDefPtr vol,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     rbd_close(image);
     return ret;
 }
@@ -382,11 +384,6 @@ static int virStorageBackendRBDRefreshPool(virConnectPtr conn,
     for (name = names; name < names + max_size;) {
         virStorageVolDefPtr vol;
 
-        if (VIR_REALLOC_N(pool->volumes.objs, pool->volumes.count + 1) < 0) {
-            virStoragePoolObjClearVols(pool);
-            goto cleanup;
-        }
-
         if (STREQ(name, ""))
             break;
 
@@ -405,7 +402,11 @@ static int virStorageBackendRBDRefreshPool(virConnectPtr conn,
             goto cleanup;
         }
 
-        pool->volumes.objs[pool->volumes.count++] = vol;
+        if (VIR_APPEND_ELEMENT(pool->volumes.objs, pool->volumes.count, vol) < 0) {
+            virStorageVolDefFree(vol);
+            virStoragePoolObjClearVols(pool);
+            goto cleanup;
+        }
     }
 
     VIR_DEBUG("Found %zu images in RBD pool %s",
@@ -413,7 +414,7 @@ static int virStorageBackendRBDRefreshPool(virConnectPtr conn,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(names);
     virStorageBackendRBDCloseRADOSConn(&ptr);
     return ret;
@@ -453,7 +454,7 @@ static int virStorageBackendRBDDeleteVol(virConnectPtr conn,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virStorageBackendRBDCloseRADOSConn(&ptr);
     return ret;
 }
@@ -544,7 +545,7 @@ virStorageBackendRBDBuildVol(virConnectPtr conn,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virStorageBackendRBDCloseRADOSConn(&ptr);
     return ret;
 }
@@ -572,7 +573,7 @@ static int virStorageBackendRBDRefreshVol(virConnectPtr conn,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     virStorageBackendRBDCloseRADOSConn(&ptr);
     return ret;
 }
@@ -616,7 +617,7 @@ static int virStorageBackendRBDResizeVol(virConnectPtr conn ATTRIBUTE_UNUSED,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     if (image != NULL)
        rbd_close(image);
     virStorageBackendRBDCloseRADOSConn(&ptr);
