@@ -52,6 +52,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_STORAGE
 
+VIR_LOG_INIT("storage.storage_driver");
+
 static virStorageDriverStatePtr driverState;
 
 static int storageStateCleanup(void);
@@ -66,7 +68,8 @@ static void storageDriverUnlock(virStorageDriverStatePtr driver)
 }
 
 static void
-storageDriverAutostart(virStorageDriverStatePtr driver) {
+storageDriverAutostart(virStorageDriverStatePtr driver)
+{
     size_t i;
     virConnectPtr conn = NULL;
 
@@ -185,7 +188,7 @@ storageStateInitialize(bool privileged,
     storageDriverUnlock(driverState);
     return 0;
 
-error:
+ error:
     VIR_FREE(base);
     storageDriverUnlock(driverState);
     storageStateCleanup();
@@ -215,7 +218,8 @@ storageStateAutoStart(void)
  * files and update its state
  */
 static int
-storageStateReload(void) {
+storageStateReload(void)
+{
     if (!driverState)
         return -1;
 
@@ -236,7 +240,8 @@ storageStateReload(void) {
  * Shutdown the storage driver, it will stop all active storage pools
  */
 static int
-storageStateCleanup(void) {
+storageStateCleanup(void)
+{
     if (!driverState)
         return -1;
 
@@ -258,7 +263,8 @@ storageStateCleanup(void) {
 
 static virStoragePoolPtr
 storagePoolLookupByUUID(virConnectPtr conn,
-                        const unsigned char *uuid) {
+                        const unsigned char *uuid)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStoragePoolPtr ret = NULL;
@@ -279,7 +285,7 @@ storagePoolLookupByUUID(virConnectPtr conn,
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -287,7 +293,8 @@ cleanup:
 
 static virStoragePoolPtr
 storagePoolLookupByName(virConnectPtr conn,
-                        const char *name) {
+                        const char *name)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStoragePoolPtr ret = NULL;
@@ -308,14 +315,15 @@ storagePoolLookupByName(virConnectPtr conn,
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
 }
 
 static virStoragePoolPtr
-storagePoolLookupByVolume(virStorageVolPtr vol) {
+storagePoolLookupByVolume(virStorageVolPtr vol)
+{
     virStorageDriverStatePtr driver = vol->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStoragePoolPtr ret = NULL;
@@ -336,7 +344,7 @@ storagePoolLookupByVolume(virStorageVolPtr vol) {
     ret = virGetStoragePool(vol->conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -357,13 +365,15 @@ storageOpen(virConnectPtr conn,
 }
 
 static int
-storageClose(virConnectPtr conn) {
+storageClose(virConnectPtr conn)
+{
     conn->storagePrivateData = NULL;
     return 0;
 }
 
 static int
-storageConnectNumOfStoragePools(virConnectPtr conn) {
+storageConnectNumOfStoragePools(virConnectPtr conn)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     size_t i;
     int nactive = 0;
@@ -388,7 +398,8 @@ storageConnectNumOfStoragePools(virConnectPtr conn) {
 static int
 storageConnectListStoragePools(virConnectPtr conn,
                                char **const names,
-                               int nnames) {
+                               int nnames)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     int got = 0;
     size_t i;
@@ -422,7 +433,8 @@ storageConnectListStoragePools(virConnectPtr conn,
 }
 
 static int
-storageConnectNumOfDefinedStoragePools(virConnectPtr conn) {
+storageConnectNumOfDefinedStoragePools(virConnectPtr conn)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     size_t i;
     int nactive = 0;
@@ -447,7 +459,8 @@ storageConnectNumOfDefinedStoragePools(virConnectPtr conn) {
 static int
 storageConnectListDefinedStoragePools(virConnectPtr conn,
                                       char **const names,
-                                      int nnames) {
+                                      int nnames)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     int got = 0;
     size_t i;
@@ -516,7 +529,7 @@ storageConnectFindStoragePoolSources(virConnectPtr conn,
 
     ret = backend->findPoolSources(conn, srcSpec, flags);
 
-cleanup:
+ cleanup:
     return ret;
 }
 
@@ -540,7 +553,7 @@ static int storagePoolIsActive(virStoragePoolPtr pool)
 
     ret = virStoragePoolObjIsActive(obj);
 
-cleanup:
+ cleanup:
     if (obj)
         virStoragePoolObjUnlock(obj);
     return ret;
@@ -565,7 +578,7 @@ static int storagePoolIsPersistent(virStoragePoolPtr pool)
 
     ret = obj->configFile ? 1 : 0;
 
-cleanup:
+ cleanup:
     if (obj)
         virStoragePoolObjUnlock(obj);
     return ret;
@@ -625,7 +638,7 @@ storagePoolCreateXML(virConnectPtr conn,
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     virStoragePoolDefFree(def);
     if (pool)
         virStoragePoolObjUnlock(pool);
@@ -675,7 +688,7 @@ storagePoolDefineXML(virConnectPtr conn,
     ret = virGetStoragePool(conn, pool->def->name, pool->def->uuid,
                             NULL, NULL);
 
-cleanup:
+ cleanup:
     virStoragePoolDefFree(def);
     if (pool)
         virStoragePoolObjUnlock(pool);
@@ -684,7 +697,8 @@ cleanup:
 }
 
 static int
-storagePoolUndefine(virStoragePoolPtr obj) {
+storagePoolUndefine(virStoragePoolPtr obj)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     int ret = -1;
@@ -731,7 +745,7 @@ storagePoolUndefine(virStoragePoolPtr obj) {
     pool = NULL;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     storageDriverUnlock(driver);
@@ -785,7 +799,7 @@ storagePoolCreate(virStoragePoolPtr obj,
     pool->active = 1;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -793,7 +807,8 @@ cleanup:
 
 static int
 storagePoolBuild(virStoragePoolPtr obj,
-                 unsigned int flags) {
+                 unsigned int flags)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStorageBackendPtr backend;
@@ -827,7 +842,7 @@ storagePoolBuild(virStoragePoolPtr obj,
         goto cleanup;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -835,7 +850,8 @@ cleanup:
 
 
 static int
-storagePoolDestroy(virStoragePoolPtr obj) {
+storagePoolDestroy(virStoragePoolPtr obj)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStorageBackendPtr backend;
@@ -888,7 +904,7 @@ storagePoolDestroy(virStoragePoolPtr obj) {
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     storageDriverUnlock(driver);
@@ -897,7 +913,8 @@ cleanup:
 
 static int
 storagePoolDelete(virStoragePoolPtr obj,
-                  unsigned int flags) {
+                  unsigned int flags)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStorageBackendPtr backend;
@@ -943,7 +960,7 @@ storagePoolDelete(virStoragePoolPtr obj,
     VIR_INFO("Deleting storage pool '%s'", pool->def->name);
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1004,7 +1021,7 @@ storagePoolRefresh(virStoragePoolPtr obj,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     storageDriverUnlock(driver);
@@ -1014,7 +1031,8 @@ cleanup:
 
 static int
 storagePoolGetInfo(virStoragePoolPtr obj,
-                   virStoragePoolInfoPtr info) {
+                   virStoragePoolInfoPtr info)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     int ret = -1;
@@ -1045,7 +1063,7 @@ storagePoolGetInfo(virStoragePoolPtr obj,
     info->available = pool->def->available;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1082,7 +1100,7 @@ storagePoolGetXMLDesc(virStoragePoolPtr obj,
 
     ret = virStoragePoolDefFormat(def);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1090,7 +1108,8 @@ cleanup:
 
 static int
 storagePoolGetAutostart(virStoragePoolPtr obj,
-                        int *autostart) {
+                        int *autostart)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     int ret = -1;
@@ -1115,7 +1134,7 @@ storagePoolGetAutostart(virStoragePoolPtr obj,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1123,7 +1142,8 @@ cleanup:
 
 static int
 storagePoolSetAutostart(virStoragePoolPtr obj,
-                        int autostart) {
+                        int autostart)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     int ret = -1;
@@ -1176,7 +1196,7 @@ storagePoolSetAutostart(virStoragePoolPtr obj,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     storageDriverUnlock(driver);
@@ -1185,7 +1205,8 @@ cleanup:
 
 
 static int
-storagePoolNumOfVolumes(virStoragePoolPtr obj) {
+storagePoolNumOfVolumes(virStoragePoolPtr obj)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     int ret = -1;
@@ -1216,7 +1237,7 @@ storagePoolNumOfVolumes(virStoragePoolPtr obj) {
             ret++;
     }
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1225,7 +1246,8 @@ cleanup:
 static int
 storagePoolListVolumes(virStoragePoolPtr obj,
                        char **const names,
-                       int maxnames) {
+                       int maxnames)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     size_t i;
@@ -1276,7 +1298,8 @@ storagePoolListVolumes(virStoragePoolPtr obj,
 static int
 storagePoolListAllVolumes(virStoragePoolPtr pool,
                           virStorageVolPtr **vols,
-                          unsigned int flags) {
+                          unsigned int flags)
+{
     virStorageDriverStatePtr driver = pool->conn->storagePrivateData;
     virStoragePoolObjPtr obj;
     size_t i;
@@ -1349,7 +1372,8 @@ storagePoolListAllVolumes(virStoragePoolPtr pool,
 
 static virStorageVolPtr
 storageVolLookupByName(virStoragePoolPtr obj,
-                       const char *name) {
+                       const char *name)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStorageVolDefPtr vol;
@@ -1386,7 +1410,7 @@ storageVolLookupByName(virStoragePoolPtr obj,
     ret = virGetStorageVol(obj->conn, pool->def->name, vol->name, vol->key,
                            NULL, NULL);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1395,7 +1419,8 @@ cleanup:
 
 static virStorageVolPtr
 storageVolLookupByKey(virConnectPtr conn,
-                      const char *key) {
+                      const char *key)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     size_t i;
     virStorageVolPtr ret = NULL;
@@ -1427,14 +1452,15 @@ storageVolLookupByKey(virConnectPtr conn,
         virReportError(VIR_ERR_NO_STORAGE_VOL,
                        _("no storage vol with matching key %s"), key);
 
-cleanup:
+ cleanup:
     storageDriverUnlock(driver);
     return ret;
 }
 
 static virStorageVolPtr
 storageVolLookupByPath(virConnectPtr conn,
-                       const char *path) {
+                       const char *path)
+{
     virStorageDriverStatePtr driver = conn->storagePrivateData;
     size_t i;
     virStorageVolPtr ret = NULL;
@@ -1446,49 +1472,80 @@ storageVolLookupByPath(virConnectPtr conn,
 
     storageDriverLock(driver);
     for (i = 0; i < driver->pools.count && !ret; i++) {
-        virStoragePoolObjLock(driver->pools.objs[i]);
-        if (virStoragePoolObjIsActive(driver->pools.objs[i])) {
-            virStorageVolDefPtr vol;
-            char *stable_path;
+        virStoragePoolObjPtr pool = driver->pools.objs[i];
+        virStorageVolDefPtr vol;
+        char *stable_path = NULL;
 
-            stable_path = virStorageBackendStablePath(driver->pools.objs[i],
-                                                      cleanpath,
-                                                      false);
-            if (stable_path == NULL) {
-                /* Don't break the whole lookup process if it fails on
-                 * getting the stable path for some of the pools.
-                 */
-                VIR_WARN("Failed to get stable path for pool '%s'",
-                         driver->pools.objs[i]->def->name);
-                virStoragePoolObjUnlock(driver->pools.objs[i]);
-                continue;
-            }
+        virStoragePoolObjLock(pool);
 
-            vol = virStorageVolDefFindByPath(driver->pools.objs[i],
-                                             stable_path);
-            VIR_FREE(stable_path);
+        if (!virStoragePoolObjIsActive(pool)) {
+           virStoragePoolObjUnlock(pool);
+           continue;
+        }
 
-            if (vol) {
-                if (virStorageVolLookupByPathEnsureACL(conn, driver->pools.objs[i]->def, vol) < 0) {
-                    virStoragePoolObjUnlock(driver->pools.objs[i]);
+        switch ((enum virStoragePoolType) pool->def->type) {
+            case VIR_STORAGE_POOL_DIR:
+            case VIR_STORAGE_POOL_FS:
+            case VIR_STORAGE_POOL_NETFS:
+            case VIR_STORAGE_POOL_LOGICAL:
+            case VIR_STORAGE_POOL_DISK:
+            case VIR_STORAGE_POOL_ISCSI:
+            case VIR_STORAGE_POOL_SCSI:
+            case VIR_STORAGE_POOL_MPATH:
+                stable_path = virStorageBackendStablePath(pool,
+                                                          cleanpath,
+                                                          false);
+                if (stable_path == NULL) {
+                    /* Don't break the whole lookup process if it fails on
+                     * getting the stable path for some of the pools.
+                     */
+                    VIR_WARN("Failed to get stable path for pool '%s'",
+                             pool->def->name);
+                    virStoragePoolObjUnlock(pool);
+                    continue;
+                }
+                break;
+
+            case VIR_STORAGE_POOL_GLUSTER:
+            case VIR_STORAGE_POOL_RBD:
+            case VIR_STORAGE_POOL_SHEEPDOG:
+            case VIR_STORAGE_POOL_LAST:
+                if (VIR_STRDUP(stable_path, path) < 0) {
+                     virStoragePoolObjUnlock(pool);
                     goto cleanup;
                 }
-
-                ret = virGetStorageVol(conn,
-                                       driver->pools.objs[i]->def->name,
-                                       vol->name,
-                                       vol->key,
-                                       NULL, NULL);
-            }
+                break;
         }
-        virStoragePoolObjUnlock(driver->pools.objs[i]);
+
+        vol = virStorageVolDefFindByPath(pool, stable_path);
+        VIR_FREE(stable_path);
+
+        if (vol) {
+            if (virStorageVolLookupByPathEnsureACL(conn, pool->def, vol) < 0) {
+                virStoragePoolObjUnlock(pool);
+                goto cleanup;
+            }
+
+            ret = virGetStorageVol(conn, pool->def->name,
+                                   vol->name, vol->key,
+                                   NULL, NULL);
+        }
+
+        virStoragePoolObjUnlock(pool);
     }
 
-    if (!ret)
-        virReportError(VIR_ERR_NO_STORAGE_VOL,
-                       _("no storage vol with matching path %s"), path);
+    if (!ret) {
+        if (STREQ(path, cleanpath)) {
+            virReportError(VIR_ERR_NO_STORAGE_VOL,
+                           _("no storage vol with matching path '%s'"), path);
+        } else {
+            virReportError(VIR_ERR_NO_STORAGE_VOL,
+                           _("no storage vol with matching path '%s' (%s)"),
+                           path, cleanpath);
+        }
+    }
 
-cleanup:
+ cleanup:
     VIR_FREE(cleanpath);
     storageDriverUnlock(driver);
     return ret;
@@ -1571,7 +1628,7 @@ storageVolDelete(virStorageVolPtr obj,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -1699,7 +1756,7 @@ storageVolCreateXML(virStoragePoolPtr obj,
     volobj = NULL;
     voldef = NULL;
 
-cleanup:
+ cleanup:
     virObjectUnref(volobj);
     virStorageVolDefFree(voldef);
     VIR_FREE(buildvoldef);
@@ -1876,7 +1933,7 @@ storageVolCreateXMLFrom(virStoragePoolPtr obj,
     ret = volobj;
     volobj = NULL;
 
-cleanup:
+ cleanup:
     virObjectUnref(volobj);
     virStorageVolDefFree(newvol);
     if (pool)
@@ -1909,13 +1966,13 @@ storageVolDownload(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_POOL,
                        _("no storage pool with matching name '%s'"),
                        obj->pool);
-        goto out;
+        goto cleanup;
     }
 
     if (!virStoragePoolObjIsActive(pool)) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("storage pool '%s' is not active"), pool->def->name);
-        goto out;
+        goto cleanup;
     }
 
     vol = virStorageVolDefFindByName(pool, obj->name);
@@ -1924,28 +1981,28 @@ storageVolDownload(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_VOL,
                        _("no storage vol with matching name '%s'"),
                        obj->name);
-        goto out;
+        goto cleanup;
     }
 
     if (virStorageVolDownloadEnsureACL(obj->conn, pool->def, vol) < 0)
-        goto out;
+        goto cleanup;
 
     if (vol->building) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("volume '%s' is still being allocated."),
                        vol->name);
-        goto out;
+        goto cleanup;
     }
 
     if (virFDStreamOpenFile(stream,
                             vol->target.path,
                             offset, length,
                             O_RDONLY) < 0)
-        goto out;
+        goto cleanup;
 
     ret = 0;
 
-out:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
 
@@ -1975,13 +2032,13 @@ storageVolUpload(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_POOL,
                        _("no storage pool with matching name '%s'"),
                        obj->pool);
-        goto out;
+        goto cleanup;
     }
 
     if (!virStoragePoolObjIsActive(pool)) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("storage pool '%s' is not active"), pool->def->name);
-        goto out;
+        goto cleanup;
     }
 
     vol = virStorageVolDefFindByName(pool, obj->name);
@@ -1990,30 +2047,49 @@ storageVolUpload(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_VOL,
                        _("no storage vol with matching name '%s'"),
                        obj->name);
-        goto out;
+        goto cleanup;
     }
 
     if (virStorageVolUploadEnsureACL(obj->conn, pool->def, vol) < 0)
-        goto out;
+        goto cleanup;
 
     if (vol->building) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("volume '%s' is still being allocated."),
                        vol->name);
-        goto out;
+        goto cleanup;
     }
 
-    /* Not using O_CREAT because the file is required to
-     * already exist at this point */
-    if (virFDStreamOpenFile(stream,
-                            vol->target.path,
-                            offset, length,
-                            O_WRONLY) < 0)
-        goto out;
+    switch ((enum virStoragePoolType) pool->def->type) {
+    case VIR_STORAGE_POOL_DIR:
+    case VIR_STORAGE_POOL_FS:
+    case VIR_STORAGE_POOL_NETFS:
+    case VIR_STORAGE_POOL_LOGICAL:
+    case VIR_STORAGE_POOL_DISK:
+    case VIR_STORAGE_POOL_ISCSI:
+    case VIR_STORAGE_POOL_SCSI:
+    case VIR_STORAGE_POOL_MPATH:
+        /* Not using O_CREAT because the file is required to already exist at
+         * this point */
+        if (virFDStreamOpenFile(stream, vol->target.path,
+                                offset, length, O_WRONLY) < 0)
+            goto cleanup;
+
+        break;
+
+    case VIR_STORAGE_POOL_SHEEPDOG:
+    case VIR_STORAGE_POOL_RBD:
+    case VIR_STORAGE_POOL_GLUSTER:
+    case VIR_STORAGE_POOL_LAST:
+        virReportError(VIR_ERR_OPERATION_UNSUPPORTED,
+                       _("volume upload is not supported with pools of type %s"),
+                       virStoragePoolTypeToString(pool->def->type));
+        goto cleanup;
+    }
 
     ret = 0;
 
-out:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
 
@@ -2044,17 +2120,17 @@ storageVolResize(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_POOL,
                        _("no storage pool with matching name '%s'"),
                        obj->pool);
-        goto out;
+        goto cleanup;
     }
 
     if (!virStoragePoolObjIsActive(pool)) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("storage pool '%s' is not active"), pool->def->name);
-        goto out;
+        goto cleanup;
     }
 
     if ((backend = virStorageBackendForType(pool->def->type)) == NULL)
-        goto out;
+        goto cleanup;
 
     vol = virStorageVolDefFindByName(pool, obj->name);
 
@@ -2062,17 +2138,17 @@ storageVolResize(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_VOL,
                        _("no storage vol with matching name '%s'"),
                        obj->name);
-        goto out;
+        goto cleanup;
     }
 
     if (virStorageVolResizeEnsureACL(obj->conn, pool->def, vol) < 0)
-        goto out;
+        goto cleanup;
 
     if (vol->building) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("volume '%s' is still being allocated."),
                        vol->name);
-        goto out;
+        goto cleanup;
     }
 
     if (flags & VIR_STORAGE_VOL_RESIZE_DELTA) {
@@ -2086,7 +2162,7 @@ storageVolResize(virStorageVolPtr obj,
         virReportError(VIR_ERR_INVALID_ARG, "%s",
                        _("can't shrink capacity below "
                          "existing allocation"));
-        goto out;
+        goto cleanup;
     }
 
     if (abs_capacity < vol->capacity &&
@@ -2094,24 +2170,24 @@ storageVolResize(virStorageVolPtr obj,
         virReportError(VIR_ERR_INVALID_ARG, "%s",
                        _("Can't shrink capacity below current "
                          "capacity with shrink flag explicitly specified"));
-        goto out;
+        goto cleanup;
     }
 
     if (abs_capacity > vol->capacity + pool->def->available) {
         virReportError(VIR_ERR_OPERATION_FAILED, "%s",
                        _("Not enough space left on storage pool"));
-        goto out;
+        goto cleanup;
     }
 
     if (!backend->resizeVol) {
         virReportError(VIR_ERR_NO_SUPPORT, "%s",
                        _("storage pool does not support changing of "
                          "volume capacity"));
-        goto out;
+        goto cleanup;
     }
 
     if (backend->resizeVol(obj->conn, pool, vol, abs_capacity, flags) < 0)
-        goto out;
+        goto cleanup;
 
     vol->capacity = abs_capacity;
     if (flags & VIR_STORAGE_VOL_RESIZE_ALLOCATE)
@@ -2123,7 +2199,7 @@ storageVolResize(virStorageVolPtr obj,
 
     ret = 0;
 
-out:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
 
@@ -2157,7 +2233,7 @@ storageVolZeroSparseFile(virStorageVolDefPtr vol,
                              _("Failed to truncate volume with "
                                "path '%s' to 0 bytes"),
                              vol->target.path);
-        goto out;
+        return ret;
     }
 
     ret = ftruncate(fd, size);
@@ -2168,7 +2244,6 @@ storageVolZeroSparseFile(virStorageVolDefPtr vol,
                              vol->target.path, (uintmax_t)size);
     }
 
-out:
     return ret;
 }
 
@@ -2194,7 +2269,7 @@ storageWipeExtent(virStorageVolDefPtr vol,
                              _("Failed to seek to position %ju in volume "
                                "with path '%s'"),
                              (uintmax_t)extent_start, vol->target.path);
-        goto out;
+        goto cleanup;
     }
 
     remaining = extent_length;
@@ -2208,7 +2283,7 @@ storageWipeExtent(virStorageVolDefPtr vol,
                                    "storage volume with path '%s'"),
                                  write_size, vol->target.path);
 
-            goto out;
+            goto cleanup;
         }
 
         *bytes_wiped += written;
@@ -2220,7 +2295,7 @@ storageWipeExtent(virStorageVolDefPtr vol,
         virReportSystemError(errno,
                              _("cannot sync data to volume with path '%s'"),
                              vol->target.path);
-        goto out;
+        goto cleanup;
     }
 
     VIR_DEBUG("Wrote %zu bytes to volume with path '%s'",
@@ -2228,7 +2303,7 @@ storageWipeExtent(virStorageVolDefPtr vol,
 
     ret = 0;
 
-out:
+ cleanup:
     return ret;
 }
 
@@ -2251,14 +2326,14 @@ storageVolWipeInternal(virStorageVolDefPtr def,
         virReportSystemError(errno,
                              _("Failed to open storage volume with path '%s'"),
                              def->target.path);
-        goto out;
+        goto cleanup;
     }
 
     if (fstat(fd, &st) == -1) {
         virReportSystemError(errno,
                              _("Failed to stat storage volume with path '%s'"),
                              def->target.path);
-        goto out;
+        goto cleanup;
     }
 
     if (algorithm != VIR_STORAGE_VOL_WIPE_ALG_ZERO) {
@@ -2298,17 +2373,17 @@ storageVolWipeInternal(virStorageVolDefPtr def,
                              def->target.path, NULL);
 
         if (virCommandRun(cmd, NULL) < 0)
-            goto out;
+            goto cleanup;
 
         ret = 0;
-        goto out;
+        goto cleanup;
     } else {
         if (S_ISREG(st.st_mode) && st.st_blocks < (st.st_size / DEV_BSIZE)) {
             ret = storageVolZeroSparseFile(def, st.st_size, fd);
         } else {
 
             if (VIR_ALLOC_N(writebuf, st.st_blksize) < 0)
-                goto out;
+                goto cleanup;
 
             ret = storageWipeExtent(def,
                                     fd,
@@ -2320,7 +2395,7 @@ storageVolWipeInternal(virStorageVolDefPtr def,
         }
     }
 
-out:
+ cleanup:
     virCommandFree(cmd);
     VIR_FREE(writebuf);
     VIR_FORCE_CLOSE(fd);
@@ -2355,13 +2430,13 @@ storageVolWipePattern(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_POOL,
                        _("no storage pool with matching name '%s'"),
                        obj->pool);
-        goto out;
+        goto cleanup;
     }
 
     if (!virStoragePoolObjIsActive(pool)) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("storage pool '%s' is not active"), pool->def->name);
-        goto out;
+        goto cleanup;
     }
 
     vol = virStorageVolDefFindByName(pool, obj->name);
@@ -2370,26 +2445,26 @@ storageVolWipePattern(virStorageVolPtr obj,
         virReportError(VIR_ERR_NO_STORAGE_VOL,
                        _("no storage vol with matching name '%s'"),
                        obj->name);
-        goto out;
+        goto cleanup;
     }
 
     if (virStorageVolWipePatternEnsureACL(obj->conn, pool->def, vol) < 0)
-        goto out;
+        goto cleanup;
 
     if (vol->building) {
         virReportError(VIR_ERR_OPERATION_INVALID,
                        _("volume '%s' is still being allocated."),
                        vol->name);
-        goto out;
+        goto cleanup;
     }
 
     if (storageVolWipeInternal(vol, algorithm) == -1) {
-        goto out;
+        goto cleanup;
     }
 
     ret = 0;
 
-out:
+ cleanup:
     if (pool) {
         virStoragePoolObjUnlock(pool);
     }
@@ -2408,7 +2483,8 @@ storageVolWipe(virStorageVolPtr obj,
 
 static int
 storageVolGetInfo(virStorageVolPtr obj,
-                  virStorageVolInfoPtr info) {
+                  virStorageVolInfoPtr info)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStorageBackendPtr backend;
@@ -2457,7 +2533,7 @@ storageVolGetInfo(virStorageVolPtr obj,
     info->allocation = vol->allocation;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -2513,7 +2589,7 @@ storageVolGetXMLDesc(virStorageVolPtr obj,
 
     ret = virStorageVolDefFormat(pool->def, vol);
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
 
@@ -2521,7 +2597,8 @@ cleanup:
 }
 
 static char *
-storageVolGetPath(virStorageVolPtr obj) {
+storageVolGetPath(virStorageVolPtr obj)
+{
     virStorageDriverStatePtr driver = obj->conn->storagePrivateData;
     virStoragePoolObjPtr pool;
     virStorageVolDefPtr vol;
@@ -2557,7 +2634,7 @@ storageVolGetPath(virStorageVolPtr obj) {
 
     ignore_value(VIR_STRDUP(ret, vol->target.path));
 
-cleanup:
+ cleanup:
     if (pool)
         virStoragePoolObjUnlock(pool);
     return ret;
@@ -2581,7 +2658,7 @@ storageConnectListAllStoragePools(virConnectPtr conn,
                                       virConnectListAllStoragePoolsCheckACL, flags);
     storageDriverUnlock(driver);
 
-cleanup:
+ cleanup:
     return ret;
 }
 
@@ -2647,7 +2724,8 @@ int storageRegister(void)
 {
     if (virRegisterStorageDriver(&storageDriver) < 0)
         return -1;
-    virRegisterStateDriver(&stateDriver);
+    if (virRegisterStateDriver(&stateDriver) < 0)
+        return -1;
     return 0;
 }
 
@@ -2701,7 +2779,7 @@ virStorageFileInitInternal(int type,
 
     return file;
 
-error:
+ error:
     VIR_FREE(file->path);
     virDomainDiskHostDefFree(file->nhosts, file->hosts);
     VIR_FREE(file);
@@ -2713,10 +2791,10 @@ virStorageFilePtr
 virStorageFileInitFromDiskDef(virDomainDiskDefPtr disk)
 {
     return virStorageFileInitInternal(virDomainDiskGetActualType(disk),
-                                      disk->src,
-                                      disk->protocol,
-                                      disk->nhosts,
-                                      disk->hosts);
+                                      disk->src.path,
+                                      disk->src.protocol,
+                                      disk->src.nhosts,
+                                      disk->src.hosts);
 }
 
 
