@@ -69,6 +69,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_UML
 
+VIR_LOG_INIT("uml.uml_driver");
+
 /* For storing short-lived temporary files. */
 #define TEMPDIR LOCALSTATEDIR "/cache/libvirt"
 
@@ -207,7 +209,8 @@ umlAutostartDomain(virDomainObjPtr vm,
 }
 
 static void
-umlAutostartConfigs(struct uml_driver *driver) {
+umlAutostartConfigs(struct uml_driver *driver)
+{
     /* XXX: Figure out a better way todo this. The domain
      * startup code needs a connection handle in order
      * to lookup the bridge associated with a virtual
@@ -239,7 +242,7 @@ umlIdentifyOneChrPTY(struct uml_driver *driver,
     int retries = 0;
     if (virAsprintf(&cmd, "config %s%d", dev, def->target.port) < 0)
         return -1;
-requery:
+ requery:
     if (umlMonitorCommand(driver, dom, cmd, &res) < 0)
         return -1;
 
@@ -306,7 +309,7 @@ umlInotifyEvent(int watch,
     if (watch != driver->inotifyWatch)
         goto cleanup;
 
-reread:
+ reread:
     got = read(fd, buf, sizeof(buf));
     if (got == -1) {
         if (errno == EINTR)
@@ -411,7 +414,7 @@ reread:
         }
     }
 
-cleanup:
+ cleanup:
     umlDriverUnlock(driver);
 }
 
@@ -573,10 +576,10 @@ umlStateInitialize(bool privileged,
     virNWFilterRegisterCallbackDriver(&umlCallbackDriver);
     return 0;
 
-out_of_memory:
+ out_of_memory:
     VIR_ERROR(_("umlStartup: out of memory"));
 
-error:
+ error:
     VIR_FREE(userdir);
     VIR_FREE(base);
     umlDriverUnlock(uml_driver);
@@ -620,7 +623,8 @@ static void umlNotifyLoadDomain(virDomainObjPtr vm, int newVM, void *opaque)
  * files and update its state and the networking
  */
 static int
-umlStateReload(void) {
+umlStateReload(void)
+{
     if (!uml_driver)
         return 0;
 
@@ -658,7 +662,8 @@ umlShutdownOneVM(virDomainObjPtr dom, void *opaque)
  * Shutdown the Uml daemon, it will stop all active domains and networks
  */
 static int
-umlStateCleanup(void) {
+umlStateCleanup(void)
+{
     if (!uml_driver)
         return -1;
 
@@ -804,7 +809,7 @@ static int umlReadPidFile(struct uml_driver *driver,
                     driver->monitorDir, vm->def->name) < 0)
         return -1;
 
-reopen:
+ reopen:
     if (!(file = fopen(pidfile, "r"))) {
         if (errno == ENOENT &&
             retries++ < 50) {
@@ -857,7 +862,8 @@ static int umlMonitorAddress(const struct uml_driver *driver,
 }
 
 static int umlOpenMonitor(struct uml_driver *driver,
-                          virDomainObjPtr vm) {
+                          virDomainObjPtr vm)
+{
     struct sockaddr_un addr;
     struct stat sb;
     int retries = 0;
@@ -867,7 +873,7 @@ static int umlOpenMonitor(struct uml_driver *driver,
         return -1;
 
     VIR_DEBUG("Dest address for monitor is '%s'", addr.sun_path);
-restat:
+ restat:
     if (stat(addr.sun_path, &sb) < 0) {
         if (errno == ENOENT &&
             retries++ < 50) {
@@ -999,13 +1005,14 @@ static int umlMonitorCommand(const struct uml_driver *driver,
 
     return ret;
 
-error:
+ error:
     VIR_FREE(retdata);
     return -1;
 }
 
 
-static void umlCleanupTapDevices(virDomainObjPtr vm) {
+static void umlCleanupTapDevices(virDomainObjPtr vm)
+{
     size_t i;
 
     for (i = 0; i < vm->def->nnets; i++) {
@@ -1022,7 +1029,8 @@ static void umlCleanupTapDevices(virDomainObjPtr vm) {
 static int umlStartVMDaemon(virConnectPtr conn,
                             struct uml_driver *driver,
                             virDomainObjPtr vm,
-                            bool autoDestroy) {
+                            bool autoDestroy)
+{
     int ret = -1;
     char *logfile;
     int logfd = -1;
@@ -1118,7 +1126,7 @@ static int umlStartVMDaemon(virConnectPtr conn,
         goto cleanup;
 
     ret = virDomainObjSetDefTransient(driver->caps, driver->xmlopt, vm, false);
-cleanup:
+ cleanup:
     VIR_FORCE_CLOSE(logfd);
     virCommandFree(cmd);
 
@@ -1243,7 +1251,8 @@ static virDrvOpenStatus umlConnectOpen(virConnectPtr conn,
     return VIR_DRV_OPEN_SUCCESS;
 }
 
-static int umlConnectClose(virConnectPtr conn) {
+static int umlConnectClose(virConnectPtr conn)
+{
     struct uml_driver *driver = conn->privateData;
 
     umlDriverLock(driver);
@@ -1341,7 +1350,8 @@ static int umlGetProcessInfo(unsigned long long *cpuTime, pid_t pid)
 
 
 static virDomainPtr umlDomainLookupByID(virConnectPtr conn,
-                                          int id) {
+                                          int id)
+{
     struct uml_driver *driver = (struct uml_driver *)conn->privateData;
     virDomainObjPtr vm;
     virDomainPtr dom = NULL;
@@ -1361,14 +1371,15 @@ static virDomainPtr umlDomainLookupByID(virConnectPtr conn,
     dom = virGetDomain(conn, vm->def->name, vm->def->uuid);
     if (dom) dom->id = vm->def->id;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return dom;
 }
 
 static virDomainPtr umlDomainLookupByUUID(virConnectPtr conn,
-                                            const unsigned char *uuid) {
+                                            const unsigned char *uuid)
+{
     struct uml_driver *driver = (struct uml_driver *)conn->privateData;
     virDomainObjPtr vm;
     virDomainPtr dom = NULL;
@@ -1388,14 +1399,15 @@ static virDomainPtr umlDomainLookupByUUID(virConnectPtr conn,
     dom = virGetDomain(conn, vm->def->name, vm->def->uuid);
     if (dom) dom->id = vm->def->id;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return dom;
 }
 
 static virDomainPtr umlDomainLookupByName(virConnectPtr conn,
-                                            const char *name) {
+                                            const char *name)
+{
     struct uml_driver *driver = (struct uml_driver *)conn->privateData;
     virDomainObjPtr vm;
     virDomainPtr dom = NULL;
@@ -1415,7 +1427,7 @@ static virDomainPtr umlDomainLookupByName(virConnectPtr conn,
     dom = virGetDomain(conn, vm->def->name, vm->def->uuid);
     if (dom) dom->id = vm->def->id;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return dom;
@@ -1441,7 +1453,7 @@ static int umlDomainIsActive(virDomainPtr dom)
 
     ret = virDomainObjIsActive(obj);
 
-cleanup:
+ cleanup:
     if (obj)
         virObjectUnlock(obj);
     return ret;
@@ -1467,7 +1479,7 @@ static int umlDomainIsPersistent(virDomainPtr dom)
 
     ret = obj->persistent;
 
-cleanup:
+ cleanup:
     if (obj)
         virObjectUnlock(obj);
     return ret;
@@ -1492,13 +1504,14 @@ static int umlDomainIsUpdated(virDomainPtr dom)
 
     ret = obj->updated;
 
-cleanup:
+ cleanup:
     if (obj)
         virObjectUnlock(obj);
     return ret;
 }
 
-static int umlConnectGetVersion(virConnectPtr conn, unsigned long *version) {
+static int umlConnectGetVersion(virConnectPtr conn, unsigned long *version)
+{
     struct uml_driver *driver = conn->privateData;
     struct utsname ut;
     int ret = -1;
@@ -1521,7 +1534,7 @@ static int umlConnectGetVersion(virConnectPtr conn, unsigned long *version) {
     *version = driver->umlVersion;
     ret = 0;
 
-cleanup:
+ cleanup:
     umlDriverUnlock(driver);
     return ret;
 }
@@ -1536,7 +1549,8 @@ static char *umlConnectGetHostname(virConnectPtr conn)
 }
 
 
-static int umlConnectListDomains(virConnectPtr conn, int *ids, int nids) {
+static int umlConnectListDomains(virConnectPtr conn, int *ids, int nids)
+{
     struct uml_driver *driver = conn->privateData;
     int n;
 
@@ -1550,7 +1564,8 @@ static int umlConnectListDomains(virConnectPtr conn, int *ids, int nids) {
 
     return n;
 }
-static int umlConnectNumOfDomains(virConnectPtr conn) {
+static int umlConnectNumOfDomains(virConnectPtr conn)
+{
     struct uml_driver *driver = conn->privateData;
     int n;
 
@@ -1565,7 +1580,8 @@ static int umlConnectNumOfDomains(virConnectPtr conn) {
     return n;
 }
 static virDomainPtr umlDomainCreateXML(virConnectPtr conn, const char *xml,
-                                       unsigned int flags) {
+                                       unsigned int flags)
+{
     struct uml_driver *driver = conn->privateData;
     virDomainDefPtr def;
     virDomainObjPtr vm = NULL;
@@ -1607,7 +1623,7 @@ static virDomainPtr umlDomainCreateXML(virConnectPtr conn, const char *xml,
     dom = virGetDomain(conn, vm->def->name, vm->def->uuid);
     if (dom) dom->id = vm->def->id;
 
-cleanup:
+ cleanup:
     virDomainDefFree(def);
     if (vm)
         virObjectUnlock(vm);
@@ -1620,7 +1636,8 @@ cleanup:
 
 
 static int umlDomainShutdownFlags(virDomainPtr dom,
-                                  unsigned int flags) {
+                                  unsigned int flags)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     char *info = NULL;
@@ -1649,7 +1666,7 @@ static int umlDomainShutdownFlags(virDomainPtr dom,
     ret = 0;
 #endif
 
-cleanup:
+ cleanup:
     VIR_FREE(info);
     if (vm)
         virObjectUnlock(vm);
@@ -1696,7 +1713,7 @@ umlDomainDestroyFlags(virDomainPtr dom,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     if (event)
@@ -1732,7 +1749,7 @@ static char *umlDomainGetOSType(virDomainPtr dom) {
     if (VIR_STRDUP(type, vm->def->os.type) < 0)
         goto cleanup;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return type;
@@ -1764,13 +1781,14 @@ umlDomainGetMaxMemory(virDomainPtr dom)
 
     ret = vm->def->mem.max_balloon;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return ret;
 }
 
-static int umlDomainSetMaxMemory(virDomainPtr dom, unsigned long newmax) {
+static int umlDomainSetMaxMemory(virDomainPtr dom, unsigned long newmax)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     int ret = -1;
@@ -1800,13 +1818,14 @@ static int umlDomainSetMaxMemory(virDomainPtr dom, unsigned long newmax) {
     vm->def->mem.max_balloon = newmax;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return ret;
 }
 
-static int umlDomainSetMemory(virDomainPtr dom, unsigned long newmem) {
+static int umlDomainSetMemory(virDomainPtr dom, unsigned long newmem)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     int ret = -1;
@@ -1842,14 +1861,15 @@ static int umlDomainSetMemory(virDomainPtr dom, unsigned long newmem) {
     vm->def->mem.cur_balloon = newmem;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return ret;
 }
 
 static int umlDomainGetInfo(virDomainPtr dom,
-                              virDomainInfoPtr info) {
+                              virDomainInfoPtr info)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     int ret = -1;
@@ -1884,7 +1904,7 @@ static int umlDomainGetInfo(virDomainPtr dom,
     info->nrVirtCpu = vm->def->vcpus;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return ret;
@@ -1919,7 +1939,7 @@ umlDomainGetState(virDomainPtr dom,
     *state = virDomainObjGetState(vm, reason);
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return ret;
@@ -1952,7 +1972,7 @@ static char *umlDomainGetXMLDesc(virDomainPtr dom,
                              vm->newDef : vm->def,
                              flags);
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     return ret;
@@ -1975,7 +1995,8 @@ static int umlConnectListDefinedDomains(virConnectPtr conn,
     return n;
 }
 
-static int umlConnectNumOfDefinedDomains(virConnectPtr conn) {
+static int umlConnectNumOfDefinedDomains(virConnectPtr conn)
+{
     struct uml_driver *driver = conn->privateData;
     int n;
 
@@ -1991,7 +2012,8 @@ static int umlConnectNumOfDefinedDomains(virConnectPtr conn) {
 }
 
 
-static int umlDomainCreateWithFlags(virDomainPtr dom, unsigned int flags) {
+static int umlDomainCreateWithFlags(virDomainPtr dom, unsigned int flags)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     virObjectEventPtr event = NULL;
@@ -2020,7 +2042,7 @@ static int umlDomainCreateWithFlags(virDomainPtr dom, unsigned int flags) {
                                          VIR_DOMAIN_EVENT_STARTED,
                                          VIR_DOMAIN_EVENT_STARTED_BOOTED);
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     if (event)
@@ -2030,11 +2052,13 @@ cleanup:
     return ret;
 }
 
-static int umlDomainCreate(virDomainPtr dom) {
+static int umlDomainCreate(virDomainPtr dom)
+{
     return umlDomainCreateWithFlags(dom, 0);
 }
 
-static virDomainPtr umlDomainDefineXML(virConnectPtr conn, const char *xml) {
+static virDomainPtr umlDomainDefineXML(virConnectPtr conn, const char *xml)
+{
     struct uml_driver *driver = conn->privateData;
     virDomainDefPtr def;
     virDomainObjPtr vm = NULL;
@@ -2067,7 +2091,7 @@ static virDomainPtr umlDomainDefineXML(virConnectPtr conn, const char *xml) {
     dom = virGetDomain(conn, vm->def->name, vm->def->uuid);
     if (dom) dom->id = vm->def->id;
 
-cleanup:
+ cleanup:
     virDomainDefFree(def);
     if (vm)
         virObjectUnlock(vm);
@@ -2113,7 +2137,7 @@ static int umlDomainUndefineFlags(virDomainPtr dom,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     umlDriverUnlock(driver);
@@ -2142,13 +2166,14 @@ static int umlDomainAttachUmlDisk(struct uml_driver *driver,
         }
     }
 
-    if (!disk->src) {
+    if (!virDomainDiskGetSource(disk)) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        "%s", _("disk source path is missing"));
         goto error;
     }
 
-    if (virAsprintf(&cmd, "config %s=%s", disk->dst, disk->src) < 0)
+    if (virAsprintf(&cmd, "config %s=%s", disk->dst,
+                    virDomainDiskGetSource(disk)) < 0)
         return -1;
 
     if (umlMonitorCommand(driver, vm, cmd, &reply) < 0)
@@ -2164,7 +2189,7 @@ static int umlDomainAttachUmlDisk(struct uml_driver *driver,
 
     return 0;
 
-error:
+ error:
 
     VIR_FREE(reply);
     VIR_FREE(cmd);
@@ -2223,7 +2248,7 @@ static int umlDomainAttachDevice(virDomainPtr dom, const char *xml)
         goto cleanup;
     }
 
-cleanup:
+ cleanup:
 
     virDomainDeviceDefFree(dev);
     if (vm)
@@ -2288,14 +2313,15 @@ static int umlDomainDetachUmlDisk(struct uml_driver *driver,
 
     VIR_FREE(reply);
 
-cleanup:
+ cleanup:
     VIR_FREE(cmd);
 
     return ret;
 }
 
 
-static int umlDomainDetachDevice(virDomainPtr dom, const char *xml) {
+static int umlDomainDetachDevice(virDomainPtr dom, const char *xml)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     virDomainDeviceDefPtr dev = NULL;
@@ -2338,7 +2364,7 @@ static int umlDomainDetachDevice(virDomainPtr dom, const char *xml) {
                        "%s", _("This type of device cannot be hot unplugged"));
     }
 
-cleanup:
+ cleanup:
     virDomainDeviceDefFree(dev);
     if (vm)
         virObjectUnlock(vm);
@@ -2365,7 +2391,8 @@ umlDomainDetachDeviceFlags(virDomainPtr dom,
 
 
 static int umlDomainGetAutostart(virDomainPtr dom,
-                            int *autostart) {
+                            int *autostart)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     int ret = -1;
@@ -2385,7 +2412,7 @@ static int umlDomainGetAutostart(virDomainPtr dom,
     *autostart = vm->autostart;
     ret = 0;
 
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     umlDriverUnlock(driver);
@@ -2393,7 +2420,8 @@ cleanup:
 }
 
 static int umlDomainSetAutostart(virDomainPtr dom,
-                                   int autostart) {
+                                   int autostart)
+{
     struct uml_driver *driver = dom->conn->privateData;
     virDomainObjPtr vm;
     char *configFile = NULL, *autostartLink = NULL;
@@ -2452,7 +2480,7 @@ static int umlDomainSetAutostart(virDomainPtr dom,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(configFile);
     VIR_FREE(autostartLink);
     if (vm)
@@ -2524,7 +2552,7 @@ umlDomainBlockPeek(virDomainPtr dom,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FORCE_CLOSE(fd);
     if (vm)
         virObjectUnlock(vm);
@@ -2598,7 +2626,7 @@ umlDomainOpenConsole(virDomainPtr dom,
         goto cleanup;
 
     ret = 0;
-cleanup:
+ cleanup:
     if (vm)
         virObjectUnlock(vm);
     umlDriverUnlock(driver);
@@ -2908,8 +2936,11 @@ static virStateDriver umlStateDriver = {
     .stateReload = umlStateReload,
 };
 
-int umlRegister(void) {
-    virRegisterDriver(&umlDriver);
-    virRegisterStateDriver(&umlStateDriver);
+int umlRegister(void)
+{
+    if (virRegisterDriver(&umlDriver) < 0)
+        return -1;
+    if (virRegisterStateDriver(&umlStateDriver) < 0)
+        return -1;
     return 0;
 }
