@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2013 Red Hat, Inc.
+ * Copyright (C) 2010-2014 Red Hat, Inc.
  * Copyright IBM Corp. 2008
  *
  * This library is free software; you can redistribute it and/or
@@ -37,6 +37,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_NONE
 
+VIR_LOG_INIT("util.netdevveth");
+
 /* Functions */
 
 virMutex virNetDevVethCreateMutex;
@@ -183,7 +185,7 @@ int virNetDevVethCreate(char** veth1, char** veth2)
 
         VIR_DEBUG("Failed to create veth host: %s guest: %s: %d",
                   *veth1 ? *veth1 : veth1auto,
-                  *veth1 ? *veth1 : veth1auto,
+                  *veth2 ? *veth2 : veth2auto,
                   status);
         VIR_FREE(veth1auto);
         VIR_FREE(veth2auto);
@@ -195,7 +197,7 @@ int virNetDevVethCreate(char** veth1, char** veth2)
                    _("Failed to allocate free veth pair after %d attempts"),
                    MAX_VETH_RETRIES);
 
-cleanup:
+ cleanup:
     virMutexUnlock(&virNetDevVethCreateMutex);
     virCommandFree(cmd);
     VIR_FREE(veth1auto);
@@ -235,7 +237,7 @@ int virNetDevVethDelete(const char *veth)
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     virCommandFree(cmd);
     return ret;
 }
