@@ -36,7 +36,6 @@
 #include <unistd.h>
 
 #include "virscsi.h"
-#include "virlog.h"
 #include "viralloc.h"
 #include "virfile.h"
 #include "virutil.h"
@@ -47,6 +46,11 @@
 
 /* For virReportOOMError()  and virReportSystemError() */
 #define VIR_FROM_THIS VIR_FROM_NONE
+struct _virUsedByInfo {
+    char *drvname; /* which driver */
+    char *domname; /* which domain */
+};
+typedef struct _virUsedByInfo *virUsedByInfoPtr;
 
 struct _virSCSIDevice {
     unsigned int adapter;
@@ -57,7 +61,7 @@ struct _virSCSIDevice {
     char *name; /* adapter:bus:target:unit */
     char *id;   /* model:vendor */
     char *sg_path; /* e.g. /dev/sg2 */
-    char **used_by; /* name of the domains using this dev */
+    virUsedByInfoPtr *used_by; /* driver:domain(s) using this dev */
     size_t n_used_by; /* how many domains are using this dev */
 
     bool readonly;
@@ -137,7 +141,7 @@ virSCSIDeviceGetSgName(const char *sysfs_prefix,
             goto cleanup;
     }
 
-cleanup:
+ cleanup:
     closedir(dir);
     VIR_FREE(path);
     return sg;
@@ -182,7 +186,7 @@ virSCSIDeviceGetDevName(const char *sysfs_prefix,
         break;
     }
 
-cleanup:
+ cleanup:
     closedir(dir);
     VIR_FREE(path);
     return name;
@@ -252,7 +256,7 @@ virSCSIDeviceNew(const char *sysfs_prefix,
         goto cleanup;
 
     ret = dev;
-cleanup:
+ cleanup:
     VIR_FREE(sg);
     VIR_FREE(vendor);
     VIR_FREE(model);
@@ -263,6 +267,14 @@ cleanup:
     return ret;
 }
 
+static void
+virSCSIDeviceUsedByInfoFree(virUsedByInfoPtr used_by)
+{
+    VIR_FREE(used_by->drvname);
+    VIR_FREE(used_by->domname);
+    VIR_FREE(used_by);
+}
+
 void
 virSCSIDeviceFree(virSCSIDevicePtr dev)
 {
@@ -275,21 +287,31 @@ virSCSIDeviceFree(virSCSIDevicePtr dev)
     VIR_FREE(dev->name);
     VIR_FREE(dev->sg_path);
     for (i = 0; i < dev->n_used_by; i++)
-        VIR_FREE(dev->used_by[i]);
+        virSCSIDeviceUsedByInfoFree(dev->used_by[i]);
     VIR_FREE(dev->used_by);
     VIR_FREE(dev);
 }
 
 int
 virSCSIDeviceSetUsedBy(virSCSIDevicePtr dev,
-                       const char *name)
+                       const char *drvname,
+                       const char *domname)
 {
-    char *copy = NULL;
-
-    if (VIR_STRDUP(copy, name) < 0)
+    virUsedByInfoPtr copy;
+    if (VIR_ALLOC(copy) < 0)
         return -1;
+    if (VIR_STRDUP(copy->drvname, drvname) < 0 ||
+        VIR_STRDUP(copy->domname, domname) < 0)
+        goto cleanup;
 
-    return VIR_APPEND_ELEMENT(dev->used_by, dev->n_used_by, copy);
+    if (VIR_APPEND_ELEMENT(dev->used_by, dev->n_used_by, copy) < 0)
+        goto cleanup;
+
+    return 0;
+
+ cleanup:
+    virSCSIDeviceUsedByInfoFree(copy);
+    return -1;
 }
 
 bool
@@ -427,15 +449,17 @@ virSCSIDeviceListSteal(virSCSIDeviceListPtr list,
 void
 virSCSIDeviceListDel(virSCSIDeviceListPtr list,
                      virSCSIDevicePtr dev,
-                     const char *name)
+                     const char *drvname,
+                     const char *domname)
 {
     virSCSIDevicePtr tmp = NULL;
     size_t i;
 
     for (i = 0; i < dev->n_used_by; i++) {
-        if (STREQ_NULLABLE(dev->used_by[i], name)) {
+        if (STREQ_NULLABLE(dev->used_by[i]->drvname, drvname) &&
+            STREQ_NULLABLE(dev->used_by[i]->domname, domname)) {
             if (dev->n_used_by > 1) {
-                VIR_FREE(dev->used_by[i]);
+                virSCSIDeviceUsedByInfoFree(dev->used_by[i]);
                 VIR_DELETE_ELEMENT(dev->used_by, i, dev->n_used_by);
             } else {
                 tmp = virSCSIDeviceListSteal(list, dev);
