@@ -1,7 +1,7 @@
 /*
  * virsysinfo.c: get SMBIOS/sysinfo information from the host
  *
- * Copyright (C) 2010-2013 Red Hat, Inc.
+ * Copyright (C) 2010-2014 Red Hat, Inc.
  * Copyright (C) 2010 Daniel Veillard
  *
  * This library is free software; you can redistribute it and/or
@@ -32,7 +32,6 @@
 
 #include "virerror.h"
 #include "virsysinfo.h"
-#include "virlog.h"
 #include "viralloc.h"
 #include "vircommand.h"
 #include "virfile.h"
@@ -216,7 +215,8 @@ virSysinfoParseProcessor(const char *base, virSysinfoDefPtr ret)
 /* virSysinfoRead for PowerPC
  * Gathers sysinfo data from /proc/cpuinfo */
 virSysinfoDefPtr
-virSysinfoRead(void) {
+virSysinfoRead(void)
+{
     virSysinfoDefPtr ret = NULL;
     char *outbuf = NULL;
 
@@ -239,7 +239,7 @@ virSysinfoRead(void) {
 
     return ret;
 
-no_memory:
+ no_memory:
     VIR_FREE(outbuf);
     return NULL;
 }
@@ -325,7 +325,7 @@ virSysinfoParseProcessor(const char *base, virSysinfoDefPtr ret)
     VIR_FREE(processor_type);
     return 0;
 
-error:
+ error:
     VIR_FREE(processor_type);
     return -1;
 }
@@ -333,7 +333,8 @@ error:
 /* virSysinfoRead for ARMv7
  * Gathers sysinfo data from /proc/cpuinfo */
 virSysinfoDefPtr
-virSysinfoRead(void) {
+virSysinfoRead(void)
+{
     virSysinfoDefPtr ret = NULL;
     char *outbuf = NULL;
 
@@ -356,7 +357,7 @@ virSysinfoRead(void) {
 
     return ret;
 
-no_memory:
+ no_memory:
     VIR_FREE(outbuf);
     return NULL;
 }
@@ -451,7 +452,7 @@ virSysinfoParseProcessor(const char *base, virSysinfoDefPtr ret)
     }
     result = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(manufacturer);
     VIR_FREE(procline);
     return result;
@@ -460,7 +461,8 @@ cleanup:
 /* virSysinfoRead for s390x
  * Gathers sysinfo data from /proc/sysinfo and /proc/cpuinfo */
 virSysinfoDefPtr
-virSysinfoRead(void) {
+virSysinfoRead(void)
+{
     virSysinfoDefPtr ret = NULL;
     char *outbuf = NULL;
 
@@ -494,7 +496,7 @@ virSysinfoRead(void) {
 
     return ret;
 
-no_memory:
+ no_memory:
     virSysinfoDefFree(ret);
     VIR_FREE(outbuf);
     return NULL;
@@ -508,7 +510,8 @@ no_memory:
       defined(__aarch64__) || \
       defined(__powerpc__))
 virSysinfoDefPtr
-virSysinfoRead(void) {
+virSysinfoRead(void)
+{
     /*
      * this can probably be extracted from Windows using API or registry
      * http://www.microsoft.com/whdc/system/platform/firmware/SMBIOS.mspx
@@ -819,7 +822,8 @@ virSysinfoParseMemory(const char *base, virSysinfoDefPtr ret)
 }
 
 virSysinfoDefPtr
-virSysinfoRead(void) {
+virSysinfoRead(void)
+{
     char *path;
     virSysinfoDefPtr ret = NULL;
     char *outbuf = NULL;
@@ -860,13 +864,13 @@ virSysinfoRead(void) {
     if (virSysinfoParseMemory(outbuf, ret) < 0)
         goto error;
 
-cleanup:
+ cleanup:
     VIR_FREE(outbuf);
     virCommandFree(cmd);
 
     return ret;
 
-error:
+ error:
     virSysinfoDefFree(ret);
     ret = NULL;
     goto cleanup;
@@ -880,16 +884,18 @@ virSysinfoBIOSFormat(virBufferPtr buf, virSysinfoDefPtr def)
         !def->bios_date && !def->bios_release)
         return;
 
-    virBufferAddLit(buf, "  <bios>\n");
-    virBufferEscapeString(buf, "    <entry name='vendor'>%s</entry>\n",
+    virBufferAddLit(buf, "<bios>\n");
+    virBufferAdjustIndent(buf, 2);
+    virBufferEscapeString(buf, "<entry name='vendor'>%s</entry>\n",
                           def->bios_vendor);
-    virBufferEscapeString(buf, "    <entry name='version'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='version'>%s</entry>\n",
                           def->bios_version);
-    virBufferEscapeString(buf, "    <entry name='date'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='date'>%s</entry>\n",
                           def->bios_date);
-    virBufferEscapeString(buf, "    <entry name='release'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='release'>%s</entry>\n",
                           def->bios_release);
-    virBufferAddLit(buf, "  </bios>\n");
+    virBufferAdjustIndent(buf, -2);
+    virBufferAddLit(buf, "</bios>\n");
 }
 
 static void
@@ -900,22 +906,24 @@ virSysinfoSystemFormat(virBufferPtr buf, virSysinfoDefPtr def)
         !def->system_uuid && !def->system_sku && !def->system_family)
         return;
 
-    virBufferAddLit(buf, "  <system>\n");
-    virBufferEscapeString(buf, "    <entry name='manufacturer'>%s</entry>\n",
+    virBufferAddLit(buf, "<system>\n");
+    virBufferAdjustIndent(buf, 2);
+    virBufferEscapeString(buf, "<entry name='manufacturer'>%s</entry>\n",
                           def->system_manufacturer);
-    virBufferEscapeString(buf, "    <entry name='product'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='product'>%s</entry>\n",
                           def->system_product);
-    virBufferEscapeString(buf, "    <entry name='version'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='version'>%s</entry>\n",
                           def->system_version);
-    virBufferEscapeString(buf, "    <entry name='serial'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='serial'>%s</entry>\n",
                           def->system_serial);
-    virBufferEscapeString(buf, "    <entry name='uuid'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='uuid'>%s</entry>\n",
                           def->system_uuid);
-    virBufferEscapeString(buf, "    <entry name='sku'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='sku'>%s</entry>\n",
                           def->system_sku);
-    virBufferEscapeString(buf, "    <entry name='family'>%s</entry>\n",
+    virBufferEscapeString(buf, "<entry name='family'>%s</entry>\n",
                           def->system_family);
-    virBufferAddLit(buf, "  </system>\n");
+    virBufferAdjustIndent(buf, -2);
+    virBufferAddLit(buf, "</system>\n");
 }
 
 static void
@@ -940,8 +948,8 @@ virSysinfoProcessorFormat(virBufferPtr buf, virSysinfoDefPtr def)
             !processor->processor_part_number)
             continue;
 
-        virBufferAddLit(buf, "  <processor>\n");
-        virBufferAdjustIndent(buf, 4);
+        virBufferAddLit(buf, "<processor>\n");
+        virBufferAdjustIndent(buf, 2);
         virBufferEscapeString(buf,
                               "<entry name='socket_destination'>%s</entry>\n",
                               processor->processor_socket_destination);
@@ -965,8 +973,8 @@ virSysinfoProcessorFormat(virBufferPtr buf, virSysinfoDefPtr def)
                               processor->processor_serial_number);
         virBufferEscapeString(buf, "<entry name='part_number'>%s</entry>\n",
                               processor->processor_part_number);
-        virBufferAdjustIndent(buf, -4);
-        virBufferAddLit(buf, "  </processor>\n");
+        virBufferAdjustIndent(buf, -2);
+        virBufferAddLit(buf, "</processor>\n");
     }
 }
 
@@ -991,34 +999,36 @@ virSysinfoMemoryFormat(virBufferPtr buf, virSysinfoDefPtr def)
             !memory->memory_part_number)
             continue;
 
-        virBufferAddLit(buf, "  <memory_device>\n");
-        virBufferEscapeString(buf, "    <entry name='size'>%s</entry>\n",
+        virBufferAddLit(buf, "<memory_device>\n");
+        virBufferAdjustIndent(buf, 2);
+        virBufferEscapeString(buf, "<entry name='size'>%s</entry>\n",
                               memory->memory_size);
         virBufferEscapeString(buf,
-                              "    <entry name='form_factor'>%s</entry>\n",
+                              "<entry name='form_factor'>%s</entry>\n",
                               memory->memory_form_factor);
-        virBufferEscapeString(buf, "    <entry name='locator'>%s</entry>\n",
+        virBufferEscapeString(buf, "<entry name='locator'>%s</entry>\n",
                               memory->memory_locator);
         virBufferEscapeString(buf,
-                              "    <entry name='bank_locator'>%s</entry>\n",
+                              "<entry name='bank_locator'>%s</entry>\n",
                               memory->memory_bank_locator);
-        virBufferEscapeString(buf, "    <entry name='type'>%s</entry>\n",
+        virBufferEscapeString(buf, "<entry name='type'>%s</entry>\n",
                               memory->memory_type);
         virBufferEscapeString(buf,
-                              "    <entry name='type_detail'>%s</entry>\n",
+                              "<entry name='type_detail'>%s</entry>\n",
                               memory->memory_type_detail);
-        virBufferEscapeString(buf, "    <entry name='speed'>%s</entry>\n",
+        virBufferEscapeString(buf, "<entry name='speed'>%s</entry>\n",
                               memory->memory_speed);
         virBufferEscapeString(buf,
-                              "    <entry name='manufacturer'>%s</entry>\n",
+                              "<entry name='manufacturer'>%s</entry>\n",
                               memory->memory_manufacturer);
         virBufferEscapeString(buf,
-                              "    <entry name='serial_number'>%s</entry>\n",
+                              "<entry name='serial_number'>%s</entry>\n",
                               memory->memory_serial_number);
         virBufferEscapeString(buf,
-                              "    <entry name='part_number'>%s</entry>\n",
+                              "<entry name='part_number'>%s</entry>\n",
                               memory->memory_part_number);
-        virBufferAddLit(buf, "  </memory_device>\n");
+        virBufferAdjustIndent(buf, -2);
+        virBufferAddLit(buf, "</memory_device>\n");
     }
 }
 
@@ -1043,12 +1053,14 @@ virSysinfoFormat(virBufferPtr buf, virSysinfoDefPtr def)
     }
 
     virBufferAsprintf(buf, "<sysinfo type='%s'>\n", type);
+    virBufferAdjustIndent(buf, 2);
 
     virSysinfoBIOSFormat(buf, def);
     virSysinfoSystemFormat(buf, def);
     virSysinfoProcessorFormat(buf, def);
     virSysinfoMemoryFormat(buf, def);
 
+    virBufferAdjustIndent(buf, -2);
     virBufferAddLit(buf, "</sysinfo>\n");
 
     if (virBufferError(buf)) {
@@ -1107,6 +1119,6 @@ bool virSysinfoIsEqual(virSysinfoDefPtr src,
 
     identical = true;
 
-cleanup:
+ cleanup:
     return identical;
 }
