@@ -1,5 +1,5 @@
 /*
- * xen_inofify.c: Xen notification of xml file activity in the
+ * xen_inotify.c: Xen notification of xml file activity in the
  *                following dirs:
  *                /etc/xen
  *                /var/lib/xend/domains
@@ -44,6 +44,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_XEN_INOTIFY
 
+VIR_LOG_INIT("xen.xen_inotify");
+
 static int
 xenInotifyXenCacheLookup(virConnectPtr conn,
                          const char *filename,
@@ -173,17 +175,8 @@ xenInotifyXendDomainsDirRemoveEntry(virConnectPtr conn, const char *fname)
             VIR_FREE(priv->configInfoList->doms[i]->name);
             VIR_FREE(priv->configInfoList->doms[i]);
 
-            if (i < (priv->configInfoList->count - 1))
-                memmove(priv->configInfoList->doms + i,
-                        priv->configInfoList->doms + i + 1,
-                        sizeof(*(priv->configInfoList->doms)) *
-                                (priv->configInfoList->count - (i + 1)));
-
-            if (VIR_REALLOC_N(priv->configInfoList->doms,
-                              priv->configInfoList->count - 1) < 0) {
-                ; /* Failure to reduce memory allocation isn't fatal */
-            }
-            priv->configInfoList->count--;
+            VIR_DELETE_ELEMENT(priv->configInfoList->doms, i,
+                               priv->configInfoList->count);
             return 0;
         }
     }
@@ -258,7 +251,7 @@ xenInotifyEvent(int watch ATTRIBUTE_UNUSED,
 
     xenUnifiedLock(priv);
 
-reread:
+ reread:
     got = read(fd, buf, sizeof(buf));
     if (got == -1) {
         if (errno == EINTR)
@@ -327,7 +320,7 @@ reread:
 
     }
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
 }
 
