@@ -1,7 +1,7 @@
 /*
- * xm_internal.h: helper routines for dealing with inactive domains
+ * xm_internal.c: helper routines for dealing with inactive domains
  *
- * Copyright (C) 2006-2007, 2009-2013 Red Hat, Inc.
+ * Copyright (C) 2006-2007, 2009-2014 Red Hat, Inc.
  * Copyright (C) 2006 Daniel P. Berrange
  *
  * This library is free software; you can redistribute it and/or
@@ -53,6 +53,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_XENXM
 
+VIR_LOG_INIT("xen.xm_internal");
+
 #ifdef WITH_RHEL5_API
 # define XEND_CONFIG_MAX_VERS_NET_TYPE_IOEMU 0
 # define XEND_CONFIG_MIN_VERS_PVFB_NEWCONF 2
@@ -92,7 +94,8 @@ static int xenInotifyActive(virConnectPtr conn)
 
 
 /* Release memory associated with a cached config object */
-static void xenXMConfigFree(void *payload, const void *key ATTRIBUTE_UNUSED) {
+static void xenXMConfigFree(void *payload, const void *key ATTRIBUTE_UNUSED)
+{
     xenXMConfCachePtr entry = (xenXMConfCachePtr)payload;
     virDomainDefFree(entry->def);
     VIR_FREE(entry->filename);
@@ -488,7 +491,7 @@ xenXMDomainGetInfo(virConnectPtr conn,
     xenUnifiedUnlock(priv);
     return 0;
 
-error:
+ error:
     xenUnifiedUnlock(priv);
     return -1;
 }
@@ -522,7 +525,7 @@ xenXMDomainGetXMLDesc(virConnectPtr conn,
                            priv->xmlopt,
                            false);
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -567,7 +570,7 @@ xenXMDomainSetMemory(virConnectPtr conn,
         goto cleanup;
     ret = 0;
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -611,7 +614,7 @@ xenXMDomainSetMaxMemory(virConnectPtr conn,
         goto cleanup;
     ret = 0;
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -638,7 +641,7 @@ xenXMDomainGetMaxMemory(virConnectPtr conn,
 
     ret = entry->def->mem.max_balloon;
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -716,7 +719,7 @@ xenXMDomainSetVcpusFlags(virConnectPtr conn,
         goto cleanup;
     ret = 0;
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -762,7 +765,7 @@ xenXMDomainGetVcpusFlags(virConnectPtr conn,
     ret = ((flags & VIR_DOMAIN_VCPU_MAXIMUM) ? entry->def->maxvcpus
            : entry->def->vcpus);
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -846,7 +849,7 @@ xenXMDomainLookupByName(virConnectPtr conn, const char *domname)
 
     ret = virDomainDefNew(domname, entry->def->uuid, -1);
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -889,7 +892,7 @@ xenXMDomainLookupByUUID(virConnectPtr conn, const unsigned char *uuid)
 
     ret = virDomainDefNew(entry->def->name, uuid, -1);
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -1101,7 +1104,7 @@ xenXMDomainUndefine(virConnectPtr conn,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -1115,7 +1118,10 @@ struct xenXMListIteratorContext {
 };
 
 static void
-xenXMListIterator(void *payload ATTRIBUTE_UNUSED, const void *name, void *data) {
+xenXMListIterator(void *payload ATTRIBUTE_UNUSED,
+                  const void *name,
+                  void *data)
+{
     struct xenXMListIteratorContext *ctx = data;
     virDomainDefPtr def = NULL;
 
@@ -1173,7 +1179,7 @@ xenXMListDefinedDomains(virConnectPtr conn, char **const names, int maxnames)
 
     ret = ctx.count;
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -1195,7 +1201,7 @@ xenXMNumOfDefinedDomains(virConnectPtr conn)
 
     ret = virHashSize(priv->nameConfigMap);
 
-cleanup:
+ cleanup:
     xenUnifiedUnlock(priv);
     return ret;
 }
@@ -1262,10 +1268,8 @@ xenXMDomainAttachDeviceFlags(virConnectPtr conn,
 
     case VIR_DOMAIN_DEVICE_NET:
     {
-        if (VIR_REALLOC_N(def->nets, def->nnets+1) < 0)
+        if (VIR_APPEND_ELEMENT(def->nets, def->nnets, dev->data.net) < 0)
             goto cleanup;
-        def->nets[def->nnets++] = dev->data.net;
-        dev->data.net = NULL;
         break;
     }
 
@@ -1348,12 +1352,7 @@ xenXMDomainDetachDeviceFlags(virConnectPtr conn,
                 dev->data.disk->dst &&
                 STREQ(def->disks[i]->dst, dev->data.disk->dst)) {
                 virDomainDiskDefFree(def->disks[i]);
-                if (i < (def->ndisks - 1))
-                    memmove(def->disks + i,
-                            def->disks + i + 1,
-                            sizeof(*def->disks) *
-                            (def->ndisks - (i + 1)));
-                def->ndisks--;
+                VIR_DELETE_ELEMENT(def->disks, i, def->ndisks);
                 break;
             }
         }
@@ -1365,12 +1364,7 @@ xenXMDomainDetachDeviceFlags(virConnectPtr conn,
         for (i = 0; i < def->nnets; i++) {
             if (!virMacAddrCmp(&def->nets[i]->mac, &dev->data.net->mac)) {
                 virDomainNetDefFree(def->nets[i]);
-                if (i < (def->nnets - 1))
-                    memmove(def->nets + i,
-                            def->nets + i + 1,
-                            sizeof(*def->nets) *
-                            (def->nnets - (i + 1)));
-                def->nnets--;
+                VIR_DELETE_ELEMENT(def->nets, i, def->nnets);
                 break;
             }
         }
@@ -1450,7 +1444,7 @@ xenXMDomainGetAutostart(virDomainDefPtr def,
 
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(linkname);
     VIR_FREE(config);
     return ret;
@@ -1487,7 +1481,7 @@ xenXMDomainSetAutostart(virDomainDefPtr def,
     }
     ret = 0;
 
-cleanup:
+ cleanup:
     VIR_FREE(linkname);
     VIR_FREE(config);
 
