@@ -32,7 +32,9 @@
 #include "internal.h"
 #include "testutils.h"
 #include "storage/storage_backend_sheepdog.h"
+#include "virstring.h"
 
+#define VIR_FROM_THIS VIR_FROM_NONE
 
 typedef struct {
     const char *output;
@@ -56,8 +58,7 @@ test_node_info_parser(collie_test test, char *poolxml)
     if (!(pool = virStoragePoolDefParseString(poolXmlData)))
         goto cleanup;
 
-    output = strdup(test.output);
-    if (!output)
+    if (VIR_STRDUP(output, test.output) < 0)
         goto cleanup;
 
     if (virStorageBackendSheepdogParseNodeInfo(pool, output) !=
@@ -73,7 +74,7 @@ test_node_info_parser(collie_test test, char *poolxml)
         pool->allocation == test.expected_allocation)
         ret = 0;
 
-  cleanup:
+ cleanup:
     VIR_FREE(output);
     VIR_FREE(poolXmlData);
     virStoragePoolDefFree(pool);
@@ -101,8 +102,7 @@ test_vdi_list_parser(collie_test test, char *poolxml, char *volxml)
     if (!(vol = virStorageVolDefParseString(pool, volXmlData)))
         goto cleanup;
 
-    output = strdup(test.output);
-    if (!output)
+    if (VIR_STRDUP(output, test.output) < 0)
         goto cleanup;
 
     if (virStorageBackendSheepdogParseVdiList(vol, output) !=
@@ -118,7 +118,7 @@ test_vdi_list_parser(collie_test test, char *poolxml, char *volxml)
         vol->allocation == test.expected_allocation)
         ret = 0;
 
-  cleanup:
+ cleanup:
     VIR_FREE(output);
     VIR_FREE(poolXmlData);
     VIR_FREE(volXmlData);
@@ -203,7 +203,7 @@ mymain(void)
 
     ret = 0;
 
-  cleanup:
+ cleanup:
     VIR_FREE(poolxml);
     VIR_FREE(volxml);
     return ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
